@@ -28,7 +28,7 @@
  *
  * @package TYPO3
  * @subpackage t3lib_cache
- * @version $Id: class.t3lib_cache_backend_dbbackend.php 7206 2010-03-28 14:15:16Z lolli $
+ * @version $Id: class.t3lib_cache_backend_dbbackend.php 8728 2010-08-29 13:15:33Z steffenk $
  */
 class t3lib_cache_backend_DbBackend extends t3lib_cache_backend_AbstractBackend {
 
@@ -163,22 +163,21 @@ class t3lib_cache_backend_DbBackend extends t3lib_cache_backend_AbstractBackend
 	/**
 	 * Checks if a cache entry with the specified identifier exists.
 	 *
-	 * @param unknown_type
+	 * @param string Specifies the identifier to check for existence
 	 * @return boolean TRUE if such an entry exists, FALSE if not
 	 * @author Ingo Renner <ingo@typo3.org>
 	 */
 	public function has($entryIdentifier) {
-		$hasEntry = false;
+		$hasEntry = FALSE;
 
-		$cacheEntries = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows(
-			'content',
+		$cacheEntries = $GLOBALS['TYPO3_DB']->exec_SELECTcountRows(
+			'*',
 			$this->cacheTable,
-			'identifier = ' . $GLOBALS['TYPO3_DB']->fullQuoteStr($entryIdentifier, $this->cacheTable) . ' '
-				. 'AND crdate + lifetime >= ' . $GLOBALS['EXEC_TIME']
+			'identifier = ' . $GLOBALS['TYPO3_DB']->fullQuoteStr($entryIdentifier, $this->cacheTable) .
+				' AND (crdate + lifetime >= ' . $GLOBALS['EXEC_TIME'] . ' OR lifetime = 0)'
 		);
-
-		if (count($cacheEntries) == 1) {
-			$hasEntry = true;
+		if ($cacheEntries >= 1) {
+			$hasEntry = TRUE;
 		}
 
 		return $hasEntry;
@@ -331,20 +330,20 @@ class t3lib_cache_backend_DbBackend extends t3lib_cache_backend_AbstractBackend
 	 */
 	public function collectGarbage() {
 			// Get identifiers of expired cache entries
-		$tagsEntryIdentifierRowsRessource = $GLOBALS['TYPO3_DB']->exec_SELECTquery(
+		$tagsEntryIdentifierRowsResource = $GLOBALS['TYPO3_DB']->exec_SELECTquery(
 			'identifier',
 			$this->cacheTable,
 			'crdate + lifetime < ' . $GLOBALS['EXEC_TIME'] . ' AND lifetime > 0'
 		);
 
 		$tagsEntryIdentifiers = array();
-		while ($tagsEntryIdentifierRow = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($tagsEntryIdentifierRowsRessource)) {
+		while ($tagsEntryIdentifierRow = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($tagsEntryIdentifierRowsResource)) {
 			$tagsEntryIdentifiers[] = $GLOBALS['TYPO3_DB']->fullQuoteStr(
 				$tagsEntryIdentifierRow['identifier'],
 				$this->tagsTable
 			);
 		}
-		$GLOBALS['TYPO3_DB']->sql_free_result($cacheEntryIdentifierRowsRessource);
+		$GLOBALS['TYPO3_DB']->sql_free_result($tagsEntryIdentifierRowsResource);
 
 			// Delete tag rows connected to expired cache entries
 		if (count($tagsEntryIdentifiers)) {
