@@ -35,8 +35,7 @@
  *   xxx is identifier, value is array of associated tags. This is "reverse" tag
  *   index. It provides quick access for all tags associated with this identifier
  *   and used when removing the identifier
- * - tagIndex
- *   Value is a List of all tags (array)
+ *
  * Each key is prepended with a prefix. By default prefix consists from two parts
  * separated by underscore character and ends in yet another underscore character:
  * - "TYPO3"
@@ -51,7 +50,7 @@
  *
  * @package TYPO3
  * @subpackage t3lib_cache
- * @version $Id: class.t3lib_cache_backend_memcachedbackend.php 6577 2009-11-29 13:21:28Z ohader $
+ * @version $Id: class.t3lib_cache_backend_memcachedbackend.php 8800 2010-09-16 16:17:08Z lolli $
  */
 class t3lib_cache_backend_MemcachedBackend extends t3lib_cache_backend_AbstractBackend {
 
@@ -237,7 +236,7 @@ class t3lib_cache_backend_MemcachedBackend extends t3lib_cache_backend_AbstractB
 				$chunkNumber = 1;
 
 				foreach ($data as $chunk) {
-					$success &= $this->memcache->set(
+					$success = $success && $this->memcache->set(
 						$this->identifierPrefix . $entryIdentifier . '_chunk_' . $chunkNumber,
 						$chunk,
 						$this->flags,
@@ -245,7 +244,7 @@ class t3lib_cache_backend_MemcachedBackend extends t3lib_cache_backend_AbstractB
 					);
 					$chunkNumber++;
 				}
-				$success &= $this->memcache->set(
+				$success = $success && $this->memcache->set(
 					$this->identifierPrefix . $entryIdentifier,
 					'TYPO3*chunked:' . $chunkNumber,
 					$this->flags,
@@ -262,8 +261,12 @@ class t3lib_cache_backend_MemcachedBackend extends t3lib_cache_backend_AbstractB
 
 			if ($success === TRUE) {
 				$this->removeIdentifierFromAllTags($entryIdentifier);
-				$this->addTagsToTagIndex($tags);
 				$this->addIdentifierToTags($entryIdentifier, $tags);
+			} else {
+				throw new t3lib_cache_Exception(
+					'Could not set data to memcache server.',
+					1275830266
+				);
 			}
 		} catch(Exception $exception) {
 			throw new t3lib_cache_Exception(
@@ -411,57 +414,6 @@ class t3lib_cache_backend_MemcachedBackend extends t3lib_cache_backend_AbstractB
 		}
 	}
 
-	/**
-	 * Returns an array with all known tags
-	 *
-	 * @return array
-	 * @author Karsten Dambekalns <karsten@typo3.org>
-	 * @internal
-	 */
-	protected function getTagIndex() {
-		$tagIndex = $this->memcache->get($this->identifierPrefix . 'tagIndex');
-		return ($tagIndex == false ? array() : (array)$tagIndex);
-	}
-
-	/**
-	 * Saves the tags known to the backend
-	 *
-	 * @param array Array of tags
-	 * @author Karsten Dambekalns <karsten@typo3.org>
-	 * @internal
-	 */
-	protected function setTagIndex(array $tags) {
-		$this->memcache->set($this->identifierPrefix . 'tagIndex', array_unique($tags), 0, 0);
-	}
-
-	/**
-	 * Adds the given tags to the tag index
-	 *
-	 * @param array Array of tags
-	 * @return void
-	 * @author Karsten Dambekalns <karsten@typo3.org>
-	 * @internal
-	 */
-	protected function addTagsToTagIndex(array $tags) {
-		if(count($tags)) {
-			$this->setTagIndex(array_merge($tags, $this->getTagIndex()));
-		}
-	}
-
-	/**
-	 * Removes the given tags from the tag index
-	 *
-	 * @param array $tags
-	 * @return void
-	 * @author Karsten Dambekalns <karsten@typo3.org>
-	 * @internal
-	 */
-	protected function removeTagsFromTagIndex(array $tags) {
-		if(count($tags)) {
-			$this->setTagIndex(array_diff($this->getTagIndex(), $tags));
-		}
-	}
-
 	/**
 	 * Associates the identifier with the given tags
 	 *
@@ -484,7 +436,7 @@ class t3lib_cache_backend_MemcachedBackend extends t3lib_cache_backend_AbstractB
 
 					// Update identifier-to-tag index
 				$existingTags = $this->findTagsByIdentifier($entryIdentifier);
-				if (array_search($entryIdentifier, $existingTags) === false) {
+				if (array_search($tag, $existingTags) === FALSE) {
 					$this->memcache->set($this->identifierPrefix . 'ident_' . $entryIdentifier,
 						array_merge($existingTags, $tags));
 				}
@@ -522,7 +474,6 @@ class t3lib_cache_backend_MemcachedBackend extends t3lib_cache_backend_AbstractB
 							$identifiers
 						);
 					} else {
-						$this->removeTagsFromTagIndex(array($tag));
 						$this->memcache->delete($this->identifierPrefix . 'tag_' . $tag);
 					}
 				}
