@@ -30,7 +30,7 @@
  * interaction.
  * This class is instantiated globally as $TYPO3_DB in TYPO3 scripts.
  *
- * $Id: class.t3lib_db.php 8482 2010-08-05 15:54:11Z ohader $
+ * $Id: class.t3lib_db.php 9777 2010-12-16 13:38:36Z ohader $
  *
  * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
  */
@@ -401,7 +401,7 @@ class t3lib_DB {
 
 				// Build query:
 			$query = 'INSERT INTO ' . $table .
-				'(' . implode(',', array_keys($fields_values)) . ') VALUES ' .
+				' (' . implode(',', array_keys($fields_values)) . ') VALUES ' .
 				'(' . implode(',', $fields_values) . ')';
 
 				// Return query:
@@ -1039,11 +1039,38 @@ class t3lib_DB {
 					);
 				}
 			}
+			$this->setSqlMode();
 		}
 
 		return $this->link;
 	}
 
+	/**
+	 * Fixes the SQL mode by unsetting NO_BACKSLASH_ESCAPES if found.
+	 *
+	 * @return void
+	 */
+	protected function setSqlMode() {
+		$resource = $this->sql_query('SELECT @@SESSION.sql_mode;');
+		if (is_resource($resource)) {
+			$result = $this->sql_fetch_row($resource);
+			if (isset($result[0]) && $result[0] && strpos($result[0], 'NO_BACKSLASH_ESCAPES') !== FALSE) {
+				$modes = array_diff(
+					t3lib_div::trimExplode(',', $result[0]),
+					array('NO_BACKSLASH_ESCAPES')
+				);
+				$query = 'SET sql_mode=\'' . mysql_real_escape_string(implode(',', $modes)) . '\';';
+				$success = $this->sql_query($query);
+
+				t3lib_div::sysLog(
+					'NO_BACKSLASH_ESCAPES could not be removed from SQL mode: ' . $this->sql_error(),
+					'Core',
+					3
+				);
+			}
+		}
+	}
+
 	/**
 	 * Select a MySQL database
 	 * mysql_select_db() wrapper function
