@@ -32,7 +32,7 @@
  * @author	Steffen Kamper <info@sk-typo3.de>
  * @package TYPO3
  * @subpackage t3lib
- * $Id: class.t3lib_pagerenderer.php 7231 2010-04-01 13:56:42Z steffenk $
+ * $Id: class.t3lib_pagerenderer.php 9029 2010-10-10 15:47:02Z steffenk $
  */
 class t3lib_PageRenderer implements t3lib_Singleton {
 
@@ -44,6 +44,7 @@ class t3lib_PageRenderer implements t3lib_Singleton {
 
 	protected $moveJsFromHeaderToFooter = FALSE;
 
+	/* @var t3lib_cs Instance of t3lib_cs */
 	protected $csConvObj;
 	protected $lang;
 
@@ -76,6 +77,7 @@ class t3lib_PageRenderer implements t3lib_Singleton {
 
 	// static inline code blocks
 	protected $jsInline = array ();
+	protected $jsFooterInline = array ();
 	protected $extOnReadyCode = array ();
 	protected $cssInline = array ();
 
@@ -115,6 +117,9 @@ class t3lib_PageRenderer implements t3lib_Singleton {
 
 	protected $inlineJavascriptWrap = array ();
 
+	// saves error messages generated during compression
+	protected $compressError = '';
+
 	// used by BE modules
 	public $backPath;
 
@@ -654,7 +659,7 @@ class t3lib_PageRenderer implements t3lib_Singleton {
 	 * @return void
 	 */
 	public function addJsInlineCode($name, $block, $compress = TRUE, $forceOnTop = FALSE) {
-		if (!isset($this->jsInline[$name])) {
+		if (!isset($this->jsInline[$name]) && !empty($block)) {
 			$this->jsInline[$name] = array (
 				'code'        => $block . chr(10),
 				'section'     => self::PART_HEADER,
@@ -674,7 +679,7 @@ class t3lib_PageRenderer implements t3lib_Singleton {
 	 * @return void
 	 */
 	public function addJsFooterInlineCode($name, $block, $compress = TRUE, $forceOnTop = FALSE) {
-		if (!isset($this->jsInline[$name])) {
+		if (!isset($this->jsInline[$name]) && !empty($block)) {
 			$this->jsInline[$name] = array (
 				'code'        => $block . chr(10),
 				'section'     => self::PART_FOOTER,
@@ -733,8 +738,8 @@ class t3lib_PageRenderer implements t3lib_Singleton {
 	 * @param boolean $forceOnTop
 	 * @return void
 	 */
-	public function addCssInlineBlock($name, $block, $compressed = FALSE, $forceOnTop = FALSE) {
-		if (!isset($this->cssInline[$name])) {
+	public function addCssInlineBlock($name, $block, $compress = FALSE, $forceOnTop = FALSE) {
+		if (!isset($this->cssInline[$name]) && !empty($block)) {
 			$this->cssInline[$name] = array (
 				'code'       => $block,
 				'compress'   => $compress,
@@ -959,15 +964,14 @@ class t3lib_PageRenderer implements t3lib_Singleton {
 		$jsFooterInline = '';
 		$jsFooterLibs = '';
 		$jsFooterFiles = '';
-		$noJS = FALSE;
 
-		
+
 		// preRenderHook for possible manuipulation
 		if (is_array($GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['t3lib/class.t3lib_pagerenderer.php']['render-preProcess'])) {
 			$params = array (
 				'jsLibs'         => &$this->jsLibs,
 				'jsFiles'        => &$this->jsFiles,
-				'jsFooterFiles'  => &$this->jsFiles,
+				'jsFooterFiles'  => &$this->jsFooterFiles,
 				'cssFiles'       => &$this->cssFiles,
 				'headerData'     => &$this->headerData,
 				'footerData'     => &$this->footerData,
@@ -980,7 +984,7 @@ class t3lib_PageRenderer implements t3lib_Singleton {
 		}
 
 		$jsLibs = $this->renderJsLibraries();
-		
+
 		if ($this->compressCss || $this->compressJavascript) {
 				// do the file compression
 			$this->doCompress();
@@ -1099,7 +1103,7 @@ class t3lib_PageRenderer implements t3lib_Singleton {
 		$templateFile = t3lib_div::getFileAbsFileName($this->templateFile, TRUE);
 		$template = t3lib_div::getURL($templateFile);
 
-		if ($this->removeEmptyLinesFromTemplate) {
+		if ($this->removeLineBreaksFromTemplate) {
 			$template = strtr($template, array(chr(10) => '', chr(13) => ''));
 		}
 		if ($part != self::PART_COMPLETE) {
@@ -1292,7 +1296,7 @@ class t3lib_PageRenderer implements t3lib_Singleton {
 			$params = array (
 				'jsLibs'         => &$this->jsLibs,
 				'jsFiles'        => &$this->jsFiles,
-				'jsFooterFiles'  => &$this->jsFiles,
+				'jsFooterFiles'  => &$this->jsFooterFiles,
 				'cssFiles'       => &$this->cssFiles,
 				'headerData'     => &$this->headerData,
 				'footerData'     => &$this->footerData,
@@ -1318,14 +1322,13 @@ class t3lib_PageRenderer implements t3lib_Singleton {
 				'jsFooterInline'  => &$this->jsFooterInline,
 				'jsLibs'          => &$this->jsLibs,
 				'jsFiles'         => &$this->jsFiles,
-				'jsFooterFiles'   => &$this->jsFiles,
+				'jsFooterFiles'   => &$this->jsFooterFiles,
 				'headerData'      => &$this->headerData,
 				'footerData'      => &$this->footerData,
 			);
 			t3lib_div::callUserFunction($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['jsCompressHandler'], $params, $this);
 		} else {
 				// traverse the arrays, compress files
-			$this->compressError = '';
 
 			if ($this->compressJavascript) {
 				if (count($this->jsInline)) {
