@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2004 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -27,7 +27,7 @@
 /**
  * Contains class for getting and transforming data for display in backend forms (TCEforms)
  *
- * $Id: class.t3lib_transferdata.php,v 1.16 2004/09/13 22:57:19 typo3 Exp $
+ * $Id: class.t3lib_transferdata.php 6588 2009-11-29 16:43:32Z ohader $
  * Revised for TYPO3 3.6 September/2003 by Kasper Skaarhoj
  *
  * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
@@ -37,45 +37,42 @@
  *
  *
  *
- *   98: class t3lib_transferData
+ *   99: class t3lib_transferData
  *
  *              SECTION: Getting record content, ready for display in TCEforms
- *  137:     function fetchRecord($table,$idList,$operation)
- *  223:     function renderRecord($table, $id, $pid, $row)
- *  267:     function renderRecordRaw($table, $id, $pid, $row, $TSconfig='', $tscPID=0)
- *  325:     function renderRecord_SW($data,$fieldConfig,$TSconfig,$table,$row,$field)
- *  355:     function renderRecord_groupProc($data,$fieldConfig,$TSconfig,$table,$row,$field)
- *  406:     function renderRecord_selectProc($data,$fieldConfig,$TSconfig,$table,$row,$field)
- *  469:     function renderRecord_flexProc($data,$fieldConfig,$TSconfig,$table,$row,$field)
- *  498:     function renderRecord_typesProc($totalRecordContent,$types_fieldConfig,$tscPID,$table,$pid)
+ *  138:     function fetchRecord($table,$idList,$operation)
+ *  225:     function renderRecord($table, $id, $pid, $row)
+ *  269:     function renderRecordRaw($table, $id, $pid, $row, $TSconfig='', $tscPID=0)
+ *  327:     function renderRecord_SW($data,$fieldConfig,$TSconfig,$table,$row,$field)
+ *  359:     function renderRecord_groupProc($data,$fieldConfig,$TSconfig,$table,$row,$field)
+ *  410:     function renderRecord_selectProc($data,$fieldConfig,$TSconfig,$table,$row,$field)
+ *  473:     function renderRecord_flexProc($data,$fieldConfig,$TSconfig,$table,$row,$field)
+ *  504:     function renderRecord_typesProc($totalRecordContent,$types_fieldConfig,$tscPID,$table,$pid)
+ *  545:     function renderRecord_inlineProc($data,$fieldConfig,$TSconfig,$table,$row,$field)
  *
  *              SECTION: FlexForm processing functions
- *  554:     function renderRecord_flexProc_procInData($dataPart,$dataStructArray,$pParams)
- *  583:     function renderRecord_flexProc_procInData_travDS(&$dataValues,$DSelements,$pParams)
+ *  632:     function renderRecord_flexProc_procInData($dataPart,$dataStructArray,$pParams)
+ *  661:     function renderRecord_flexProc_procInData_travDS(&$dataValues,$DSelements,$pParams)
  *
  *              SECTION: Selector box processing functions
- *  660:     function selectAddSpecial($dataAcc, $elements, $specialKey)
- *  784:     function selectAddForeign($dataAcc, $elements, $fieldConfig, $field, $TSconfig, $row)
- *  837:     function getDataIdList($elements, $fieldConfig, $row)
- *  860:     function procesItemArray($selItems,$config,$fieldTSConfig,$table,$row,$field)
- *  875:     function addItems($items,$iArray)
- *  897:     function procItems($items,$itemsProcFuncTSconfig,$config,$table,$row,$field)
+ *  738:     function selectAddSpecial($dataAcc, $elements, $specialKey)
+ *  863:     function selectAddForeign($dataAcc, $elements, $fieldConfig, $field, $TSconfig, $row, $table)
+ *  917:     function getDataIdList($elements, $fieldConfig, $row, $table)
+ *  946:     function procesItemArray($selItems,$config,$fieldTSConfig,$table,$row,$field)
+ *  961:     function addItems($items,$iArray)
+ *  983:     function procItems($items,$itemsProcFuncTSconfig,$config,$table,$row,$field)
  *
  *              SECTION: Helper functions
- *  932:     function lockRecord($table, $id, $pid=0)
- *  949:     function regItem($table, $id, $field, $content)
- *  959:     function sL($in)
+ * 1018:     function lockRecord($table, $id, $pid=0)
+ * 1035:     function regItem($table, $id, $field, $content)
+ * 1045:     function sL($in)
  *
- * TOTAL FUNCTIONS: 19
+ * TOTAL FUNCTIONS: 20
  * (This index is automatically created/updated by the extension "extdeveval")
  *
  */
 
 
-require_once (PATH_t3lib.'class.t3lib_loaddbgroup.php');
-require_once (PATH_t3lib.'class.t3lib_loadmodules.php');
-require_once (PATH_t3lib.'class.t3lib_parsehtml_proc.php');
-
 
 
 
@@ -163,6 +160,27 @@ class t3lib_transferData {
 							}
 						}
 
+						if ($id < 0) {
+							$record = t3lib_beFunc::getRecord ($table, abs($id), 'pid');
+							$pid = $record['pid'];
+							unset($record);
+						} else {
+							$pid = intval($id);
+						}
+
+						$pageTS = t3lib_beFunc::getPagesTSconfig($pid);
+
+						if (isset($pageTS['TCAdefaults.'])) {
+							$TCAPageTSOverride  = $pageTS['TCAdefaults.'];
+							if (is_array($TCAPageTSOverride[$table.'.']))	{
+								foreach($TCAPageTSOverride[$table.'.'] as $theF => $theV)	{
+									if (isset($TCA[$table]['columns'][$theF]))	{
+										$newRow[$theF]=$theV;
+									}
+								}
+							}
+						}
+
 							// Default values as submitted:
 						if (is_array($this->defVals[$table]))	{
 							foreach($this->defVals[$table] as $theF => $theV)	{
@@ -196,6 +214,7 @@ class t3lib_transferData {
 							// Fetch database values
 						$res = $GLOBALS['TYPO3_DB']->exec_SELECTquery('*', $table, 'uid='.intval($id).t3lib_BEfunc::deleteClause($table));
 						if ($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res))	{
+							t3lib_BEfunc::fixVersioningPid($table,$row);
 							$this->renderRecord($table, $id, $row['pid'], $row);
 							$contentTable = $GLOBALS['TYPO3_CONF_VARS']['SYS']['contentTable'];
 							$this->lockRecord($table, $id, $contentTable==$table?$row['pid']:0);	// Locking the pid if the table edited is the content table.
@@ -323,7 +342,6 @@ class t3lib_transferData {
 	 * @return	string		Modified $value
 	 */
 	function renderRecord_SW($data,$fieldConfig,$TSconfig,$table,$row,$field)	{
-
 		switch((string)$fieldConfig['config']['type'])	{
 			case 'group':
 				$data = $this->renderRecord_groupProc($data,$fieldConfig,$TSconfig,$table,$row,$field);
@@ -334,6 +352,9 @@ class t3lib_transferData {
 			case 'flex':
 				$data = $this->renderRecord_flexProc($data,$fieldConfig,$TSconfig,$table,$row,$field);
 			break;
+			case 'inline':
+				$data = $this->renderRecord_inlineProc($data,$fieldConfig,$TSconfig,$table,$row,$field);
+			break;
 		}
 
 		return $data;
@@ -381,7 +402,8 @@ class t3lib_transferData {
 			break;
 			case 'db':
 				$loadDB = t3lib_div::makeInstance('t3lib_loadDBGroup');
-				$loadDB->start($data, $fieldConfig['config']['allowed'], $fieldConfig['config']['MM'], $row['uid']);
+				/* @var $loadDB t3lib_loadDBGroup */
+				$loadDB->start($data, $fieldConfig['config']['allowed'], $fieldConfig['config']['MM'], $row['uid'], $table, $fieldConfig['config']);
 				$loadDB->getFromDB();
 				$data = $loadDB->readyForInterface();
 			break;
@@ -414,13 +436,14 @@ class t3lib_transferData {
 		if (intval($fieldConfig['config']['maxitems'])>1)	{
 
 				// Add regular elements:
-			if (is_array($fieldConfig['config']['items']))	{
-				$fieldConfig['config']['items'] = $this->procesItemArray($fieldConfig['config']['items'], $fieldConfig['config'], $TSconfig[$field], $table, $row, $field);
-				foreach($fieldConfig['config']['items'] as $pvpv)	{
-					foreach($elements as $eKey => $value)	{
-						if (!strcmp($value,$pvpv[1]))	{
-							$dataAcc[$eKey]=rawurlencode($pvpv[1]).'|'.rawurlencode($pvpv[0]);
-						}
+			if (!is_array($fieldConfig['config']['items']))	{
+				$fieldConfig['config']['items'] = array();
+			}
+			$fieldConfig['config']['items'] = $this->procesItemArray($fieldConfig['config']['items'], $fieldConfig['config'], $TSconfig[$field], $table, $row, $field);
+			foreach($fieldConfig['config']['items'] as $pvpv)	{
+				foreach($elements as $eKey => $value)	{
+					if (!strcmp($value,$pvpv[1]))	{
+						$dataAcc[$eKey]=rawurlencode($pvpv[1]).'|'.rawurlencode($this->sL($pvpv[0]));
 					}
 				}
 			}
@@ -432,7 +455,7 @@ class t3lib_transferData {
 
 				// Add "foreign table" stuff:
 			if ($TCA[$fieldConfig['config']['foreign_table']])	{
-				$dataAcc = $this->selectAddForeign($dataAcc, $elements, $fieldConfig, $field, $TSconfig, $row);
+				$dataAcc = $this->selectAddForeign($dataAcc, $elements, $fieldConfig, $field, $TSconfig, $row, $table);
 			}
 
 				// Always keep the native order for display in interface:
@@ -440,7 +463,7 @@ class t3lib_transferData {
 		} else {	// Normal, <= 1 -> value without title on it
 			if ($TCA[$fieldConfig['config']['foreign_table']])	{
 				// Getting the data
-				$dataIds = $this->getDataIdList($elements, $fieldConfig, $row);
+				$dataIds = $this->getDataIdList($elements, $fieldConfig, $row, $table);
 
 				if (!count($dataIds))	$dataIds = array(0);
 				$dataAcc[]=$dataIds[0];
@@ -477,7 +500,9 @@ class t3lib_transferData {
 			$dataStructArray = t3lib_BEfunc::getFlexFormDS($fieldConfig['config'],$row,$table);
 			if (is_array($dataStructArray))	{
 				$currentValueArray['data'] = $this->renderRecord_flexProc_procInData($currentValueArray['data'],$dataStructArray,array($data,$fieldConfig,$TSconfig,$table,$row,$field));
-				$data = t3lib_div::array2xml($currentValueArray);
+
+				$flexObj = t3lib_div::makeInstance('t3lib_flexformtools');
+				$data = $flexObj->flexArray2Xml($currentValueArray, TRUE);
 			}
 		}
 
@@ -522,7 +547,46 @@ class t3lib_transferData {
 		return $totalRecordContent;
 	}
 
+	/**
+	 * Processing of the data value in case the field type is "inline"
+	 * In some parts nearly the same as type "select"
+	 *
+	 * @param	string		The field value
+	 * @param	array		TCA field config
+	 * @param	array		TCEform TSconfig for the record
+	 * @param	string		Table name
+	 * @param	array		The row
+	 * @param	string		Field name
+	 * @return	string		The processed input field value ($data)
+	 * @access private
+	 * @see renderRecord()
+	 */
+	function renderRecord_inlineProc($data,$fieldConfig,$TSconfig,$table,$row,$field)	{
+		global $TCA;
 
+			// Initialize:
+		$elements = t3lib_div::trimExplode(',',$data);	// Current data set.
+		$dataAcc=array();	// New data set, ready for interface (list of values, rawurlencoded)
+
+			// At this point all records that CAN be selected is found in $recordList
+			// Now, get the data from loadDBgroup based on the input list of values.
+		$dataIds = $this->getDataIdList($elements, $fieldConfig, $row, $table);
+
+			// After this we can traverse the loadDBgroup values and match values with the list of possible values in $recordList:
+		foreach($dataIds as $theId)	{
+			if ($fieldConfig['config']['MM'] || $fieldConfig['config']['foreign_field'])	{
+				$dataAcc[]=$theId;
+			} else {
+				foreach($elements as $eKey => $value)	{
+					if (!strcmp($theId,$value))	{
+						$dataAcc[$eKey]=$theId;
+					}
+				}
+			}
+		}
+
+		return implode(',',$dataAcc);
+	}
 
 
 
@@ -591,13 +655,15 @@ class t3lib_transferData {
 					if (is_array($dataValues[$key]['el']))	{
 						if ($DSelements[$key]['section'])	{
 							foreach($dataValues[$key]['el'] as $ik => $el)	{
-								$theKey = key($el);
-								if (is_array($dataValues[$key]['el'][$ik][$theKey]['el']))	{
-									$this->renderRecord_flexProc_procInData_travDS(
-											$dataValues[$key]['el'][$ik][$theKey]['el'],
-											$DSelements[$key]['el'][$theKey]['el'],
-											$pParams
-										);
+								if (is_array($el))	{
+									$theKey = key($el);
+									if (is_array($dataValues[$key]['el'][$ik][$theKey]['el']))	{
+										$this->renderRecord_flexProc_procInData_travDS(
+												$dataValues[$key]['el'][$ik][$theKey]['el'],
+												$DSelements[$key]['el'][$theKey]['el'],
+												$pParams
+											);
+									}
 								}
 							}
 						} else {
@@ -615,7 +681,7 @@ class t3lib_transferData {
 
 								// $data,$fieldConfig,$TSconfig,$table,$row,$field
 							list(,,$CVTSconfig,$CVtable,$CVrow,$CVfield) = $pParams;
-;
+
 								// Set default value:
 							if (!isset($dataValues[$key][$vKey]))	{
 								$dataValues[$key][$vKey] = $dsConf['TCEforms']['config']['default'];
@@ -691,7 +757,7 @@ class t3lib_transferData {
 					foreach($theExcludeFields as $theExcludeFieldsArrays)	{
 						foreach($elements as $eKey => $value)	{
 							if (!strcmp($theExcludeFieldsArrays[1],$value))	{
-								$dataAcc[$eKey]=rawurlencode($value).'|'.rawurlencode(ereg_replace(':$','',$theExcludeFieldsArrays[0]));
+								$dataAcc[$eKey]=rawurlencode($value).'|'.rawurlencode(rtrim($theExcludeFieldsArrays[0], ':'));
 							}
 						}
 					}
@@ -732,7 +798,7 @@ class t3lib_transferData {
 							foreach($coValue['items'] as $itemKey => $itemCfg)	{
 								foreach($elements as $eKey => $value)	{
 									if (!strcmp($coKey.':'.$itemKey, $value))	{
-										$dataAcc[$eKey] = rawurlencode($value).'|'.rawurlencode($GLOBALS['LANG']->sl($itemCfg[0]));
+										$dataAcc[$eKey] = rawurlencode($value).'|'.rawurlencode($this->sL($itemCfg[0]));
 									}
 								}
 							}
@@ -777,11 +843,12 @@ class t3lib_transferData {
 	 * @param	string		The field name
 	 * @param	array		TSconfig for the record
 	 * @param	array		The record
+	 * @param	array		The current table
 	 * @return	array		Modified $dataAcc array
 	 * @access private
 	 * @see renderRecord_selectProc()
 	 */
-	function selectAddForeign($dataAcc, $elements, $fieldConfig, $field, $TSconfig, $row)	{
+	function selectAddForeign($dataAcc, $elements, $fieldConfig, $field, $TSconfig, $row, $table)	{
 		global $TCA;
 
 			// Init:
@@ -803,14 +870,14 @@ class t3lib_transferData {
 
 			// At this point all records that CAN be selected is found in $recordList
 			// Now, get the data from loadDBgroup based on the input list of values.
-		$dataIds = $this->getDataIdList($elements, $fieldConfig, $row);
+		$dataIds = $this->getDataIdList($elements, $fieldConfig, $row, $table);
 		if ($fieldConfig['config']['MM'])	$dataAcc=array();	// Reset, if MM (which cannot bear anything but real relations!)
 
 			// After this we can traverse the loadDBgroup values and match values with the list of possible values in $recordList:
 		foreach($dataIds as $theId)	{
 			if (isset($recordList[$theId]))	{
 				$lPrefix = $this->sL($fieldConfig['config'][($theId>0?'':'neg_').'foreign_table_prefix']);
-				if ($fieldConfig['config']['MM'])	{
+				if ($fieldConfig['config']['MM'] || $fieldConfig['config']['foreign_field'])	{
 					$dataAcc[]=rawurlencode($theId).'|'.rawurlencode(t3lib_div::fixed_lgd_cs($lPrefix.strip_tags($recordList[$theId]),$GLOBALS['BE_USER']->uc['titleLen']));
 				} else {
 					foreach($elements as $eKey => $value)	{
@@ -831,13 +898,20 @@ class t3lib_transferData {
 	 * @param	array		The array of original elements - basically the field value exploded by ","
 	 * @param	array		Field configuration from TCA
 	 * @param	array		The data array, currently. Used to set the "local_uid" for selecting MM relation records.
+	 * @param	string		Current table name. passed on to t3lib_loadDBGroup
 	 * @return	array		An array with ids of the records from the input elements array.
 	 * @access private
 	 */
-	function getDataIdList($elements, $fieldConfig, $row)	{
+	function getDataIdList($elements, $fieldConfig, $row, $table)	{
 		$loadDB = t3lib_div::makeInstance('t3lib_loadDBGroup');
 		$loadDB->registerNonTableValues=$fieldConfig['config']['allowNonIdValues'] ? 1 : 0;
-		$loadDB->start(implode(',',$elements), $fieldConfig['config']['foreign_table'].','.$fieldConfig['config']['neg_foreign_table'], $fieldConfig['config']['MM'], $row['uid']);
+		$loadDB->start(implode(',',$elements),
+			$fieldConfig['config']['foreign_table'].','.$fieldConfig['config']['neg_foreign_table'],
+			$fieldConfig['config']['MM'],
+			$row['uid'],
+			$table,
+			$fieldConfig['config']
+		);
 
 		$idList = $loadDB->convertPosNeg($loadDB->getValueArray(),$fieldConfig['config']['foreign_table'],$fieldConfig['config']['neg_foreign_table']);
 
@@ -965,4 +1039,5 @@ class t3lib_transferData {
 if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['t3lib/class.t3lib_transferdata.php'])	{
 	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['t3lib/class.t3lib_transferdata.php']);
 }
-?>
+
+?>
\ No newline at end of file
