@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2008 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -27,7 +27,7 @@
 /**
  * Contains the dynamic configuation of the fields in the core tables of TYPO3: be_users, be_groups, sys_filemounts and sys_workspace
  *
- * $Id: tbl_be.php 3656 2008-05-16 09:23:30Z dmitry $
+ * $Id: tbl_be.php 6430 2009-11-16 16:31:24Z ohader $
  * Revised for TYPO3 3.6 July/2003 by Kasper Skaarhoj
  *
  * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
@@ -45,7 +45,7 @@
 $TCA['be_users'] = array(
 	'ctrl' => $TCA['be_users']['ctrl'],
 	'interface' => array(
-		'showRecordFieldList' => 'username,usergroup,db_mountpoints,file_mountpoints,admin,options,fileoper_perms,userMods,lockToDomain,realName,email,disable,starttime,endtime'
+		'showRecordFieldList' => 'username,usergroup,db_mountpoints,file_mountpoints,admin,options,fileoper_perms,userMods,lockToDomain,realName,email,disable,starttime,endtime,lastlogin'
 	),
 	'columns' => array(
 		'username' => array(
@@ -131,7 +131,12 @@ $TCA['be_users'] = array(
 				'size' => '3',
 				'maxitems' => '10',
 				'autoSizeMax' => 10,
-				'show_thumbs' => '1'
+				'show_thumbs' => '1',
+				'wizards' => array(
+					'suggest' => array(
+						'type' => 'suggest',
+					),
+				),
 			)
 		),
 		'file_mountpoints' => array(
@@ -240,7 +245,7 @@ $TCA['be_users'] = array(
 					array('LLL:EXT:lang/locallang_tca.xml:be_users.fileoper_perms_diroper_perms_copy', 0),
 					array('LLL:EXT:lang/locallang_tca.xml:be_users.fileoper_perms_diroper_perms_delete', 0),
 				),
-				'default' => '7'
+				'default' => '0'
 			)
 		),
 		'workspace_perms' => array(
@@ -378,20 +383,32 @@ $TCA['be_users'] = array(
 			),
 			'defaultExtras' => 'fixed-font : enable-tab',
 		),
-		'createdByAction' => array('config' => array('type' => 'passthrough'))
+		'createdByAction' => array(
+			'config' => array(
+				'type' => 'passthrough'
+			)
+		),
+		'lastlogin' => array(
+			'label' => 'LLL:EXT:lang/locallang_general.php:LGL.lastlogin',
+			'config' => array(
+				'type' => 'input',
+				'readOnly' => '1',
+				'size' => '12',
+				'eval' => 'datetime',
+				'default' => 0,
+			)
+		)
 	),
 	'types' => array(
-		'0' => array('showitem' => 'disable;;;;1-1-1, username;;;;2-2-2, password, usergroup;;;;3-3-3, realName;;;;3-3-3, email, lang,
-			--div--;LLL:EXT:lang/locallang_tca.xml:be_users.tabs.rights, admin;;;;1-1-1, userMods;;;;2-2-2, allowed_languages,
+		'0' => array('showitem' => 'disable;;;;1-1-1, username;;;;2-2-2, password, usergroup;;;;3-3-3, admin;;;;1-1-1, realName;;;;3-3-3, email, lang, lastlogin;;;;1-1-1,
+			--div--;LLL:EXT:lang/locallang_tca.xml:be_users.tabs.rights, userMods;;;;2-2-2, allowed_languages,
 			--div--;LLL:EXT:lang/locallang_tca.xml:be_users.tabs.mounts_and_workspaces, workspace_perms;;;;1-1-1, db_mountpoints;;;;2-2-2, options, file_mountpoints;;;;3-3-3, fileoper_perms,
 			--div--;LLL:EXT:lang/locallang_tca.xml:be_users.tabs.options, lockToDomain;;;;1-1-1, disableIPlock, TSconfig;;;;2-2-2,
 			--div--;LLL:EXT:lang/locallang_tca.xml:be_users.tabs.access, starttime;;;;1-1-1,endtime,
 			--div--;LLL:EXT:lang/locallang_tca.xml:be_users.tabs.extended'
 		),
-		'1' => array('showitem' => 'disable;;;;1-1-1, username;;;;2-2-2, password, usergroup;;;;3-3-3, realName;;;;3-3-3, email, lang,
-			--div--;LLL:EXT:lang/locallang_tca.xml:be_users.tabs.rights, admin;;;;1-1-1, allowed_languages;;;;2-2-2,
-			--div--;LLL:EXT:lang/locallang_tca.xml:be_users.tabs.mounts_and_workspaces, db_mountpoints;;;;2-2-2, options, file_mountpoints;;;;3-3-3, fileoper_perms,
-			--div--;LLL:EXT:lang/locallang_tca.xml:be_users.tabs.options, disableIPlock;;;;1-1-1, TSconfig;;;;2-2-2,
+		'1' => array('showitem' => 'disable;;;;1-1-1, username;;;;2-2-2, password, usergroup;;;;3-3-3, admin;;;;1-1-1, realName;;;;3-3-3, email, lang, lastlogin;;;;1-1-1,
+			--div--;LLL:EXT:lang/locallang_tca.xml:be_users.tabs.options, disableIPlock;;;;1-1-1, TSconfig;;;;2-2-2, db_mountpoints;;;;3-3-3, file_mountpoints;;;;4-4-4,
 			--div--;LLL:EXT:lang/locallang_tca.xml:be_users.tabs.access, starttime;;;;1-1-1,endtime,
 			--div--;LLL:EXT:lang/locallang_tca.xml:be_users.tabs.extended'
 		)
@@ -406,7 +423,7 @@ $TCA['be_users'] = array(
 $TCA['be_groups'] = array(
 	'ctrl' => $TCA['be_groups']['ctrl'],
 	'interface' => array(
-		'showRecordFieldList' => 'title,db_mountpoints,file_mountpoints,inc_access_lists,tables_select,tables_modify,pagetypes_select,non_exclude_fields,groupMods,lockToDomain,description'
+		'showRecordFieldList' => 'title, db_mountpoints, file_mountpoints, fileoper_perms, inc_access_lists, tables_select, tables_modify, pagetypes_select, non_exclude_fields, groupMods, lockToDomain, description'
 	),
 	'columns' => array(
 		'title' => array(
@@ -427,7 +444,12 @@ $TCA['be_groups'] = array(
 				'size' => '3',
 				'maxitems' => 20,
 				'autoSizeMax' => 10,
-				'show_thumbs' => '1'
+				'show_thumbs' => '1',
+				'wizards' => array(
+					'suggest' => array(
+						'type' => 'suggest',
+					),
+				),
 			)
 		),
 		'file_mountpoints' => array(
@@ -476,6 +498,20 @@ $TCA['be_groups'] = array(
 				)
 			)
 		),
+		'fileoper_perms' => array(
+			'label' => 'LLL:EXT:lang/locallang_tca.xml:be_groups.fileoper_perms',
+			'config' => array(
+				'type' => 'check',
+				'items' => array(
+					array('LLL:EXT:lang/locallang_tca.xml:be_groups.fileoper_perms_general', 0),
+					array('LLL:EXT:lang/locallang_tca.xml:be_groups.fileoper_perms_unzip', 0),
+					array('LLL:EXT:lang/locallang_tca.xml:be_groups.fileoper_perms_diroper_perms', 0),
+					array('LLL:EXT:lang/locallang_tca.xml:be_groups.fileoper_perms_diroper_perms_copy', 0),
+					array('LLL:EXT:lang/locallang_tca.xml:be_groups.fileoper_perms_diroper_perms_delete', 0),
+				),
+				'default' => '7'
+			)
+		),
 		'workspace_perms' => array(
 			'label' => 'LLL:EXT:lang/locallang_tca.xml:workspace_perms',
 			'config' => array(
@@ -649,8 +685,18 @@ $TCA['be_groups'] = array(
 		)
 	),
 	'types' => array(
-		'0' => array('showitem' => 'hidden;;;;1-1-1, title;;;;2-2-2,description, subgroup;;;;3-3-3, --div--;LLL:EXT:lang/locallang_tca.xml:be_groups.tabs.base_rights, inc_access_lists;;;;1-1-1, --div--;LLL:EXT:lang/locallang_tca.xml:be_groups.tabs.mounts_and_workspaces, db_mountpoints;;;;1-1-1,file_mountpoints, workspace_perms;;;;2-2-2, , --div--;LLL:EXT:lang/locallang_tca.xml:be_groups.tabs.options, lockToDomain;;;;1-1-1, hide_in_lists;;;;2-2-2, TSconfig;;;;3-3-3, --div--;LLL:EXT:lang/locallang_tca.xml:be_groups.tabs.extended'),
-		'1' => array('showitem' => 'hidden;;;;1-1-1, title;;;;2-2-2,description, subgroup;;;;3-3-3, --div--;LLL:EXT:lang/locallang_tca.xml:be_groups.tabs.base_rights, inc_access_lists;;;;1-1-1, groupMods, tables_select, tables_modify, pagetypes_select, non_exclude_fields, explicit_allowdeny , allowed_languages;;;;2-2-2, custom_options;;;;3-3-3, --div--;LLL:EXT:lang/locallang_tca.xml:be_groups.tabs.mounts_and_workspaces, db_mountpoints;;;;1-1-1,file_mountpoints, workspace_perms;;;;2-2-2, --div--;LLL:EXT:lang/locallang_tca.xml:be_groups.tabs.options, lockToDomain;;;;1-1-1, hide_in_lists;;;;2-2-2, TSconfig;;;;3-3-3, --div--;LLL:EXT:lang/locallang_tca.xml:be_groups.tabs.extended')
+		'0' => array('showitem' => 'hidden;;;;1-1-1, title;;;;2-2-2, description, subgroup;;;;3-3-3,
+			--div--;LLL:EXT:lang/locallang_tca.xml:be_groups.tabs.base_rights, inc_access_lists;;;;1-1-1,
+			--div--;LLL:EXT:lang/locallang_tca.xml:be_groups.tabs.mounts_and_workspaces, workspace_perms;;;;1-1-1, db_mountpoints;;;;2-2-2, file_mountpoints;;;;3-3-3, fileoper_perms,
+			--div--;LLL:EXT:lang/locallang_tca.xml:be_groups.tabs.options, lockToDomain;;;;1-1-1, hide_in_lists;;;;2-2-2, TSconfig;;;;3-3-3,
+			--div--;LLL:EXT:lang/locallang_tca.xml:be_groups.tabs.extended'
+		),
+		'1' => array('showitem' => 'hidden;;;;1-1-1, title;;;;2-2-2, description, subgroup;;;;3-3-3,
+			--div--;LLL:EXT:lang/locallang_tca.xml:be_groups.tabs.base_rights, inc_access_lists;;;;1-1-1, groupMods, tables_select, tables_modify, pagetypes_select, non_exclude_fields, explicit_allowdeny , allowed_languages;;;;2-2-2, custom_options;;;;3-3-3,
+			--div--;LLL:EXT:lang/locallang_tca.xml:be_groups.tabs.mounts_and_workspaces, workspace_perms;;;;1-1-1, db_mountpoints;;;;2-2-2, file_mountpoints;;;;3-3-3, fileoper_perms,
+			--div--;LLL:EXT:lang/locallang_tca.xml:be_groups.tabs.options, lockToDomain;;;;1-1-1, hide_in_lists;;;;2-2-2, TSconfig;;;;3-3-3,
+			--div--;LLL:EXT:lang/locallang_tca.xml:be_groups.tabs.extended'
+		)
 	)
 );
 
@@ -709,200 +755,6 @@ $TCA['sys_filemounts'] = array(
 
 
 
-/**
- * System workspaces - Defines the offline workspaces available to users in TYPO3.
- */
-$TCA['sys_workspace'] = array(
-	'ctrl' => $TCA['sys_workspace']['ctrl'],
-	'columns' => array(
-		'title' => array(
-			'label' => 'LLL:EXT:lang/locallang_general.xml:LGL.title',
-			'config' => array(
-				'type' => 'input',
-				'size' => '20',
-				'max' => '30',
-				'eval' => 'required,trim,unique'
-			)
-		),
-		'description' => array(
-			'label' => 'LLL:EXT:lang/locallang_general.xml:LGL.description',
-			'config' => array(
-				'type' => 'text',
-				'rows' => 5,
-				'cols' => 30
-			)
-		),
-		'adminusers' => array(
-			'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace.adminusers',
-			'config' => array(
-				'type' => 'group',
-				'internal_type' => 'db',
-				'allowed' => 'be_users',
-				'size' => '3',
-				'maxitems' => '10',
-				'autoSizeMax' => 10,
-				'show_thumbs' => '1'
-			)
-		),
-		'members' => array(
-			'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace.members',
-			'config' => array(
-				'type' => 'group',
-				'internal_type' => 'db',
-				'allowed' => 'be_users,be_groups',
-				'prepend_tname' => 1,
-				'size' => '3',
-				'maxitems' => '100',
-				'autoSizeMax' => 10,
-				'show_thumbs' => '1'
-			)
-		),
-		'reviewers' => array(
-			'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace.reviewers',
-			'config' => array(
-				'type' => 'group',
-				'internal_type' => 'db',
-				'allowed' => 'be_users,be_groups',
-				'prepend_tname' => 1,
-				'size' => '3',
-				'maxitems' => '100',
-				'autoSizeMax' => 10,
-				'show_thumbs' => '1'
-			)
-		),
-		'db_mountpoints' => array(
-			'label' => 'LLL:EXT:lang/locallang_tca.xml:db_mountpoints',
-			'config' => array(
-				'type' => 'group',
-				'internal_type' => 'db',
-					'allowed' => 'pages',
-				'size' => '3',
-				'maxitems' => '10',
-				'autoSizeMax' => 10,
-				'show_thumbs' => '1'
-			)
-		),
-		'file_mountpoints' => array(
-			'label' => 'LLL:EXT:lang/locallang_tca.xml:file_mountpoints',
-			'config' => array(
-				'type' => 'select',
-				'foreign_table' => 'sys_filemounts',
-				'foreign_table_where' => ' AND sys_filemounts.pid=0 ORDER BY sys_filemounts.title',
-				'size' => '3',
-				'maxitems' => '10',
-				'autoSizeMax' => 10,
-				'renderMode' => $GLOBALS['TYPO3_CONF_VARS']['BE']['accessListRenderMode'],
-				'iconsInOptionTags' => 1,
-			)
-		),
-		'publish_time' => array(
-			'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace.publish_time',
-			'config' => array(
-				'type' => 'input',
-				'size' => '8',
-				'max' => '20',
-				'eval' => 'datetime',
-				'default' => '0',
-				'checkbox' => '0'
-			)
-		),
-		'unpublish_time' => array(
-			'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace.unpublish_time',
-			'config' => array(
-				'type' => 'input',
-				'size' => '8',
-				'max' => '20',
-				'eval' => 'datetime',
-				'checkbox' => '0',
-				'default' => '0',
-				'range' => array(
-					'upper' => mktime(0,0,0,12,31,2020),
-				)
-			)
-		),
-		'freeze' => array(
-			'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace.freeze',
-			'config' => array(
-				'type' => 'check',
-				'default' => '0'
-			)
-		),
-		'live_edit' => array(
-			'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace.live_edit',
-			'config' => array(
-				'type' => 'check',
-				'default' => '0'
-			)
-		),
-		'review_stage_edit' => array(
-			'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace.review_stage_edit',
-			'config' => array(
-				'type' => 'check',
-				'default' => '0'
-			)
-		),
-		'disable_autocreate' => array(
-			'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace.disable_autocreate',
-			'config' => array(
-				'type' => 'check',
-				'default' => '0'
-			)
-		),
-		'swap_modes' => array(
-			'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace.swap_modes',
-			'config' => array(
-				'type' => 'select',
-				'items' => array(
-					array('', 0),
-					array('Swap-Into-Workspace on Auto-publish', 1),
-					array('Disable Swap-Into-Workspace', 2)
-				),
-			)
-		),
-		'vtypes' => array(
-			'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace.vtypes',
-			'config' => array(
-				'type' => 'check',
-				'items' => array(
-					array('Element', 0),
-					array('Page', 0),
-					array('Branch', 0)
-				),
-			)
-		),
-		'publish_access' => array(
-			'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace.publish_access',
-			'config' => array(
-				'type' => 'check',
-				'items' => array(
-					array('Publish only content in publish stage', 0),
-					array('Only workspace owner can publish', 0),
-				),
-			)
-		),
-		'stagechg_notification' => array(
-			'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace.stagechg_notification',
-			'config' => array(
-				'type' => 'select',
-				'items' => array(
-					array('', 0),
-					array('Notify users on next stage only', 1),
-					array('Notify all users on any change', 10)
-				),
-			)
-		),
-	),
-	'types' => array(
-		'0' => array('showitem' => 'title,description,
-			--div--;LLL:EXT:lang/locallang_tca.xml:sys_filemounts.tabs.users,adminusers,members,reviewers,stagechg_notification,
-			--div--;LLL:EXT:lang/locallang_tca.xml:sys_filemounts.tabs.mountpoints,db_mountpoints,file_mountpoints,
-			--div--;LLL:EXT:lang/locallang_tca.xml:sys_filemounts.tabs.publishing,publish_time,unpublish_time,
-			--div--;LLL:EXT:lang/locallang_tca.xml:sys_filemounts.tabs.other,freeze,live_edit,review_stage_edit,disable_autocreate,swap_modes,vtypes,publish_access'
-		)
-	)
-);
-
-
 
 /**
  * System languages - Defines possible languages used for translation of records in the system
@@ -960,7 +812,7 @@ $TCA['sys_language'] = array(
 				'size' => 1,
 				'minitems' => 0,
 				'maxitems' => 1,
-	        )
+			)
 		)
 	),
 	'types' => array(
@@ -968,4 +820,4 @@ $TCA['sys_language'] = array(
 	)
 );
 
-?>
+?>
\ No newline at end of file
