@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2008 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -27,7 +27,7 @@
 /**
  * Folder tree in the File main module.
  *
- * $Id: alt_file_navframe.php 4571 2008-12-18 18:38:49Z steffenk $
+ * $Id: alt_file_navframe.php 6167 2009-10-19 11:59:31Z rupi $
  * Revised for TYPO3 3.6 2/2003 by Kasper Skaarhoj
  * XHTML compliant
  *
@@ -123,7 +123,8 @@ class SC_alt_file_navframe {
 			// Create template object:
 		$this->doc = t3lib_div::makeInstance('template');
 		$this->doc->backPath = $BACK_PATH;
-		$this->doc->docType = 'xhtml_trans';
+		$this->doc->setModuleTemplate('templates/alt_file_navframe.html');
+		$this->doc->showFlashMessages = FALSE;
 
 			// Adding javascript code for AJAX (prototype), drag&drop and the filetree as well as the click menu code
 		$this->doc->getDragDropCode('folders');
@@ -134,6 +135,54 @@ class SC_alt_file_navframe {
 
 		($this->currentSubScript?'top.currentSubScript=unescape("'.rawurlencode($this->currentSubScript).'");':'').'
 
+		function initFlashUploader(path) {
+			path = decodeURIComponent(path);
+			var flashUploadOptions = {
+				uploadURL: top.TS.PATH_typo3 + "ajax.php",
+				uploadFileSizeLimit: "' . t3lib_div::getMaxUploadFileSize() . '",
+				uploadFileTypes: {
+					allow:  "' . $GLOBALS['TYPO3_CONF_VARS']['BE']['fileExtensions']['webspace']['allow'] . '",
+					deny: "' . $GLOBALS['TYPO3_CONF_VARS']['BE']['fileExtensions']['webspace']['deny'] . '"
+				},
+				uploadFilePostName: "upload_1",
+				uploadPostParams: {
+					"file[upload][1][target]": path,
+					"file[upload][1][data]": 1,
+					"file[upload][1][charset]": "utf-8",
+					"ajaxID": "TYPO3_tcefile::process"
+				}
+			};
+
+				// get the flashUploaderWindow instance from the parent frame
+			var flashUploader = top.TYPO3.FileUploadWindow.getInstance(flashUploadOptions);
+				// add an additional function inside the container to show the checkbox option
+			var infoComponent = new top.Ext.Panel({
+				autoEl: { tag: "div" },
+				height: "auto",
+				bodyBorder: false,
+				border: false,
+				hideBorders: true,
+				cls: "t3-upload-window-infopanel",
+				id: "t3-upload-window-infopanel-addition",
+				html: \'<label for="overrideExistingFilesCheckbox"><input id="overrideExistingFilesCheckbox" type="checkbox" onclick="setFlashPostOptionOverwriteExistingFiles(this);" />\' + top.String.format(top.TYPO3.LLL.fileUpload.infoComponentOverrideFiles) + \'</label>\'
+			});
+			flashUploader.add(infoComponent);
+
+				// do a reload of this frame once all uploads are done
+			flashUploader.on("totalcomplete", function() {
+				jumpTo (top.rawurlencode(path), "", "", "");
+			});
+
+				// this is the callback function that delivers the additional post parameter to the flash application
+			top.setFlashPostOptionOverwriteExistingFiles = function(checkbox) {
+				var uploader = top.TYPO3.getInstance("FileUploadWindow");
+				if (uploader.isVisible()) {
+					uploader.swf.addPostParam("overwriteExistingFiles", (checkbox.checked == true ? 1 : 0));
+				}
+			};
+		}
+
+
 		// setting prefs for foldertree
 		Tree.ajaxID = "SC_alt_file_navframe::expandCollapse";
 
@@ -143,8 +192,8 @@ class SC_alt_file_navframe {
 			if (theUrl.indexOf("?") != -1) {
 				theUrl += "&id=" + id
 			} else {
-				theUrl += "?id=" + id		    	
-			}	
+				theUrl += "?id=" + id
+			}
 			top.fsMod.currentBank = bank;
 
 			if (top.condensedMode) {
@@ -173,32 +222,35 @@ class SC_alt_file_navframe {
 			// Produce browse-tree:
 		$tree = $this->foldertree->getBrowsableTree();
 
-			// Start page
-		$this->content = $this->doc->startPage('TYPO3 Folder Tree');
-
 			// Outputting page tree:
 		$this->content.= $tree;
 
-			// Outputting refresh-link
-		$this->content.= '
-			<p class="c-refresh">
-				<a href="'.htmlspecialchars(t3lib_div::getIndpEnv('REQUEST_URI')).'">'.
-				'<img'.t3lib_iconWorks::skinImg('','gfx/refresh_n.gif','width="14" height="14"').' title="'.$LANG->sL('LLL:EXT:lang/locallang_core.php:labels.refresh',1).'" alt="" />'.
-				$LANG->sL('LLL:EXT:lang/locallang_core.php:labels.refresh',1).'</a>
-			</p>
-			<br />';
-
-			// CSH icon:
-		$this->content.= t3lib_BEfunc::cshItem('xMOD_csh_corebe', 'filetree', $GLOBALS['BACK_PATH']);
-
 			// Adding javascript for drag & drop activation and highlighting
 		$this->content .=$this->doc->wrapScriptTags('
 			'.($this->doHighlight ? 'Tree.highlightActiveItem("", top.fsMod.navFrameHighlightedID["file"]);' : '').'
 			'.(!$this->doc->isCMlayers() ? 'Tree.activateDragDrop = false;' : 'Tree.registerDragDropHandlers();')
 		);
 
-	}
+			// Setting up the buttons and markers for docheader
+		$docHeaderButtons = $this->getButtons();
+		$markers = array(
+			'IMG_RESET' => '<img' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/close_gray.gif', ' width="16" height="16"') .
+			' id="treeFilterReset" alt="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.xml:labels.resetFilter') . '" ' .
+			'title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.xml:labels.resetFilter') . '" />',
+			'CONTENT' => $this->content
+		);
 
+		$subparts = array();
+
+			// Possible filter/search like in page tree
+		$subparts['###SECOND_ROW###'] = '';
+
+			// Build the <body> for the module
+		$this->content = $this->doc->startPage('TYPO3 Folder Tree');
+		$this->content.= $this->doc->moduleBody($this->pageinfo, $docHeaderButtons, $markers, $subparts);
+		$this->content.= $this->doc->endPage();
+		$this->content = $this->doc->insertStylesAndJS($this->content);
+	}
 
 	/**
 	 * Outputting the accumulated content to screen
@@ -206,11 +258,29 @@ class SC_alt_file_navframe {
 	 * @return	void
 	 */
 	function printContent()	{
-		$this->content.= $this->doc->endPage();
-		$this->content = $this->doc->insertStylesAndJS($this->content);
 		echo $this->content;
 	}
 
+	/**
+	 * Create the panel of buttons for submitting the form or otherwise perform operations.
+	 *
+	 * @return	array	all available buttons as an assoc. array
+	 */
+	protected function getButtons()	{
+		$buttons = array(
+			'csh' => '',
+			'refresh' => '',
+		);
+
+			// Refresh
+		$buttons['refresh'] = '<a href="' . htmlspecialchars(t3lib_div::getIndpEnv('REQUEST_URI')) . '">' .
+				'<img' . t3lib_iconWorks::skinImg('','gfx/refresh_n.gif','width="14" height="14"') . ' title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:labels.refresh',1) . '" alt="" /></a>';
+
+			// CSH
+		$buttons['csh'] = str_replace('typo3-csh-inline','typo3-csh-inline show-right',t3lib_BEfunc::cshItem('xMOD_csh_corebe', 'filetree', $GLOBALS['BACK_PATH']));
+
+		return $buttons;
+	}
 
 	/**********************************
 	 *
@@ -223,10 +293,10 @@ class SC_alt_file_navframe {
 	 * Called by typo3/ajax.php
 	 *
 	 * @param	array		$params: additional parameters (not used here)
-	 * @param	TYPO3AJAX	&$ajaxObj: reference of the TYPO3AJAX object of this request
+	 * @param	TYPO3AJAX	$ajaxObj: The TYPO3AJAX object of this request
 	 * @return	void
 	 */
-	public function ajaxExpandCollapse($params, &$ajaxObj)	{
+	public function ajaxExpandCollapse($params, $ajaxObj) {
 		global $LANG;
 
 		$this->init();
@@ -239,7 +309,7 @@ class SC_alt_file_navframe {
 	}
 }
 
-// Include extension?
+
 if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['typo3/alt_file_navframe.php'])	{
 	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['typo3/alt_file_navframe.php']);
 }
@@ -253,4 +323,5 @@ if (!(TYPO3_REQUESTTYPE & TYPO3_REQUESTTYPE_AJAX)) {
 	$SOBE->main();
 	$SOBE->printContent();
 }
+
 ?>
