@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2008 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -27,7 +27,7 @@
 /**
  * Displays the secondary-options palette for the TCEFORMs wherever they are shown.
  *
- * $Id: alt_palette.php 4326 2008-10-19 12:33:25Z stucki $
+ * $Id: alt_palette.php 6244 2009-10-22 08:30:40Z baschny $
  * Revised for TYPO3 3.6 November/2003 by Kasper Skaarhoj
  * XHTML compliant
  *
@@ -60,9 +60,6 @@
 
 require('init.php');
 require('template.php');
-require_once(PATH_t3lib.'class.t3lib_tceforms.php');
-require_once(PATH_t3lib.'class.t3lib_transferdata.php');
-require_once(PATH_t3lib.'class.t3lib_loaddbgroup.php');
 $LANG->includeLLFile('EXT:lang/locallang_alt_doc.xml');
 
 
@@ -77,6 +74,7 @@ $LANG->includeLLFile('EXT:lang/locallang_alt_doc.xml');
  * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
  * @package TYPO3
  * @subpackage core
+ * @deprecated since TYPO3 4.3, will be removed in TYPO3 4.5
  */
 class formRender extends t3lib_TCEforms {
 
@@ -247,15 +245,19 @@ class SC_alt_palette {
 	function init()	{
 
 			// Setting GPvars, etc.
-		$this->formName = t3lib_div::_GP('formName');
-		$this->GPbackref = t3lib_div::_GP('backRef');
+		$this->formName = $this->sanitizeHtmlName(t3lib_div::_GP('formName'));
+		$this->GPbackref = $this->sanitizeHtmlName(t3lib_div::_GP('backRef'));
 		$this->inData = t3lib_div::_GP('inData');
-		$this->prependFormFieldNames = t3lib_div::_GP('prependFormFieldNames');
+			// safeguards the input with whitelisting
+		if (!preg_match('/^[a-zA-Z0-9\-_\:]+$/', $this->inData)) {
+			$this->inData = '';
+		}
+		$this->prependFormFieldNames =
+			$this->sanitizeHtmlName(t3lib_div::_GP('prependFormFieldNames'));
 		$this->rec = t3lib_div::_GP('rec');
 
 			// Making references:
 		$this->backRef = $this->GPbackref ? $this->GPbackref : 'window.opener';
-#		$this->backRef = 'top.content.list_frame.view_frame';
 
 		$this->formRef = $this->backRef.'.document.'.$this->formName;
 
@@ -264,7 +266,6 @@ class SC_alt_palette {
 		$this->doc->bodyTagMargins['x']=0;
 		$this->doc->bodyTagMargins['y']=0;
 		$this->doc->form='<form action="#" method="post" name="'.htmlspecialchars($this->formName).'" onsubmit="return false;">';
-		$this->doc->docType = 'xhtml_trans';
 		$this->doc->backPath = '';
 
 			// In case the palette is opened in a SEPARATE window (as the case is with frontend editing) then another body-tag id should be used (so we don't get the background image for the palette shown!)
@@ -293,6 +294,24 @@ class SC_alt_palette {
 		');
 	}
 
+	/**
+	 * Sanitizes HTML names, IDs, frame names etc.
+	 *
+	 * @param string $input the string to sanitize
+	 *
+	 * @return string the unchanged $input if $input is considered to be harmless,
+	 *                an empty string otherwise
+	 */
+	protected function sanitizeHtmlName($input) {
+		$result = $input;
+
+		if (!preg_match('/^[a-zA-Z][a-zA-Z0-9_\-\.]*$/', $result)) {
+			$result = '';
+		}
+
+		return $result;
+	}
+
 	/**
 	 * Main function, rendering the palette form
 	 *
@@ -349,25 +368,17 @@ class SC_alt_palette {
 	}
 }
 
-// Include extension?
+
 if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['typo3/alt_palette.php'])	{
 	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['typo3/alt_palette.php']);
 }
 
 
 
-
-
-
-
-
-
-
-
-
 // Make instance:
 $SOBE = t3lib_div::makeInstance('SC_alt_palette');
 $SOBE->init();
 $SOBE->main();
 $SOBE->printContent();
+
 ?>
\ No newline at end of file
