@@ -26,7 +26,7 @@
 ***************************************************************/
 
 if(TYPO3_REQUESTTYPE & TYPO3_REQUESTTYPE_AJAX) {
-	require_once('interfaces/interface.backend_toolbaritem.php');
+	require_once(PATH_typo3 . 'interfaces/interface.backend_toolbaritem.php');
 	$GLOBALS['LANG']->includeLLFile('EXT:lang/locallang_misc.xml');
 
 		// needed to get the correct icons when reloading the menu after saving it
@@ -38,7 +38,7 @@ if(TYPO3_REQUESTTYPE & TYPO3_REQUESTTYPE_AJAX) {
 /**
  * class to render the shortcut menu
  *
- * $Id: class.shortcutmenu.php 5885 2009-09-03 16:49:44Z rupi $
+ * $Id: class.shortcutmenu.php 8378 2010-07-28 09:05:57Z ohader $
  *
  * @author	Ingo Renner <ingo@typo3.org>
  * @package TYPO3
@@ -148,7 +148,7 @@ class ShortcutMenu implements backend_toolbarItem {
 			<tr id="shortcut-'.$shortcut['raw']['uid'].'" class="shortcut">
 				<td class="shortcut-icon">'.$shortcut['icon'].'</td>
 				<td class="shortcut-label">
-					<a id="shortcut-label-'.$shortcut['raw']['uid'].'" href="#" onclick="'.$shortcut['action'].'; return false;">'.$shortcut['label'].'</a>
+					<a id="shortcut-label-' . $shortcut['raw']['uid'] . '" href="#" onclick="' . $shortcut['action'] . '; return false;">' . htmlspecialchars($shortcut['label']) . '</a>
 				</td>
 				<td class="shortcut-edit">'.$editIcon.' id="shortcut-edit-'.$shortcut['raw']['uid'].'" /></td>
 				<td class="shortcut-delete">'.$deleteIcon.'</td>
@@ -181,7 +181,7 @@ class ShortcutMenu implements backend_toolbarItem {
 					<tr id="shortcut-'.$shortcut['raw']['uid'].'" class="shortcut'.$firstRow.'">
 						<td class="shortcut-icon">'.$shortcut['icon'].'</td>
 						<td class="shortcut-label">
-							<a id="shortcut-label-'.$shortcut['raw']['uid'].'" href="#" onclick="'.$shortcut['action'].'; return false;">'.$shortcut['label'].'</a>
+							<a id="shortcut-label-' . $shortcut['raw']['uid'] . '" href="#" onclick="' . $shortcut['action'] . '; return false;">' . htmlspecialchars($shortcut['label']) . '</a>
 						</td>
 						<td class="shortcut-edit">'.$editIcon.' id="shortcut-edit-'.$shortcut['raw']['uid'].'" /></td>
 						<td class="shortcut-delete">'.$deleteIcon.'</td>
@@ -504,61 +504,64 @@ class ShortcutMenu implements backend_toolbarItem {
 		$queryParts      = parse_url($url);
 		$queryParameters = t3lib_div::explodeUrl2Array($queryParts['query'], 1);
 
-		if(is_array($queryParameters['edit'])) {
-			$shortcut['table']    = key($queryParameters['edit']);
-			$shortcut['recordid'] = key($queryParameters['edit'][$shortcut['table']]);
+			// Proceed only if no scheme is defined, as URL is expected to be relative
+		if (empty($queryParts['scheme'])) {
+			if (is_array($queryParameters['edit'])) {
+				$shortcut['table']    = key($queryParameters['edit']);
+				$shortcut['recordid'] = key($queryParameters['edit'][$shortcut['table']]);
 
-			if($queryParameters['edit'][$shortcut['table']][$shortcut['recordid']] == 'edit') {
-				$shortcut['type']    = 'edit';
-				$shortcutNamePrepend = $GLOBALS['LANG']->getLL('shortcut_edit', 1);
-			} elseif($queryParameters['edit'][$shortcut['table']][$shortcut['recordid']] == 'new') {
-				$shortcut['type']    = 'new';
-				$shortcutNamePrepend = $GLOBALS['LANG']->getLL('shortcut_create', 1);
+				if($queryParameters['edit'][$shortcut['table']][$shortcut['recordid']] == 'edit') {
+					$shortcut['type']    = 'edit';
+					$shortcutNamePrepend = $GLOBALS['LANG']->getLL('shortcut_edit', 1);
+				} elseif($queryParameters['edit'][$shortcut['table']][$shortcut['recordid']] == 'new') {
+					$shortcut['type']    = 'new';
+					$shortcutNamePrepend = $GLOBALS['LANG']->getLL('shortcut_create', 1);
+				}
+			} else {
+				$shortcut['type'] = 'other';
 			}
-		} else {
-			$shortcut['type'] = 'other';
-		}
 
-			// Lookup the title of this page and use it as default description
-		$pageId = $shortcut['recordid'] ? $shortcut['recordid'] : $this->getLinkedPageId($url);
+				// Lookup the title of this page and use it as default description
+			$pageId = $shortcut['recordid'] ? $shortcut['recordid'] : $this->getLinkedPageId($url);
 
-		if(t3lib_div::testInt($pageId)) {
-			$page = t3lib_BEfunc::getRecord('pages', $pageId);
-			if(count($page)) {
-					// set the name to the title of the page
-				if($shortcut['type'] == 'other') {
-					$shortcutName = $page['title'];
-				} else {
-					$shortcutName = $shortcutNamePrepend.' '.$LANG->sL($TCA[$shortcut['table']]['ctrl']['title']).' ('.$page['title'].')';
+			if(t3lib_div::testInt($pageId)) {
+				$page = t3lib_BEfunc::getRecord('pages', $pageId);
+				if(count($page)) {
+						// set the name to the title of the page
+					if($shortcut['type'] == 'other') {
+						$shortcutName = $page['title'];
+					} else {
+						$shortcutName = $shortcutNamePrepend.' '.$LANG->sL($TCA[$shortcut['table']]['ctrl']['title']).' ('.$page['title'].')';
+					}
+				}
+			} else {
+				$dirName = urldecode($pageId);
+				if (preg_match('/\/$/', $dirName))	{
+						// if $pageId is a string and ends with a slash,
+						// assume it is a fileadmin reference and set
+						// the description to the basename of that path
+					$shortcutName .= ' ' . basename($dirName);
 				}
 			}
-		} else {
-			$dirName = urldecode($pageId);
-			if (preg_match('/\/$/', $dirName))	{
-					// if $pageId is a string and ends with a slash,
-					// assume it is a fileadmin reference and set
-					// the description to the basename of that path
-				$shortcutName .= ' ' . basename($dirName);
+
+				// adding the shortcut
+			if($module && $url) {
+				$fieldValues = array(
+					'userid'      => $GLOBALS['BE_USER']->user['uid'],
+					'module_name' => $module.'|'.$motherModule,
+					'url'         => $url,
+					'description' => $shortcutName,
+					'sorting'     => $GLOBALS['EXEC_TIME'],
+				);
+				$GLOBALS['TYPO3_DB']->exec_INSERTquery('sys_be_shortcuts', $fieldValues);
+
+				if($GLOBALS['TYPO3_DB']->sql_affected_rows() == 1) {
+					$shortcutCreated = 'success';
+				}
 			}
+
+			$ajaxObj->addContent('create', $shortcutCreated);
 		}
-
-			// adding the shortcut
-		if($module && $url) {
-			$fieldValues = array(
-				'userid'      => $GLOBALS['BE_USER']->user['uid'],
-				'module_name' => $module.'|'.$motherModule,
-				'url'         => $url,
-				'description' => $shortcutName,
-				'sorting'     => $GLOBALS['EXEC_TIME'],
-			);
-			$GLOBALS['TYPO3_DB']->exec_INSERTquery('sys_be_shortcuts', $fieldValues);
-
-			if($GLOBALS['TYPO3_DB']->sql_affected_rows() == 1) {
-				$shortcutCreated = 'success';
-			}
-		}
-
-		$ajaxObj->addContent('create', $shortcutCreated);
 	}
 
 	/**
