@@ -2,7 +2,7 @@
 define('TYPO3_MOD_PATH', 'mod/user/ws/');
 $BACK_PATH='../../../';
 
-$MLANG['default']['tabs_images']['tab'] = 'sys_workspace.png';
+$MLANG['default']['tabs_images']['tab'] = 'sys_workspace.gif';
 $MLANG['default']['ll_ref']='LLL:EXT:lang/locallang_mod_user_ws.php';
 
 $MCONF['shy'] = FALSE;
