@@ -28,7 +28,7 @@
  * Shows a picture from uploads/* in enlarged format in a separate window.
  * Picture file and settings is supplied by GET-parameters: file, width, height, sample, alternativeTempPath, effects, frame, bodyTag, title, wrap, md5
  *
- * $Id: showpic.php 8744 2010-08-31 15:02:42Z ohader $
+ * $Id: showpic.php 9792 2010-12-16 13:41:33Z ohader $
  * Revised for TYPO3 3.6 June/2003 by Kasper Skaarhoj
  *
  * @author		Kasper Skaarhoj	<kasperYYYY@typo3.com>
@@ -128,7 +128,11 @@ class SC_tslib_showpic {
 	var $title;
 	var $wrap;
 	var $md5;
-	var $contentHash;
+
+	/**
+	 * @var string
+	 */
+	protected $parametersEncoded;
 
 	/**
 	 * Init function, setting the input vars in the global space.
@@ -138,17 +142,9 @@ class SC_tslib_showpic {
 	function init()	{
 			// Loading internal vars with the GET/POST parameters from outside:
 		$this->file = t3lib_div::_GP('file');
-		$this->width = t3lib_div::_GP('width');
-		$this->height = t3lib_div::_GP('height');
-		$this->sample = t3lib_div::_GP('sample');
-		$this->alternativeTempPath = t3lib_div::_GP('alternativeTempPath');
-		$this->effects = t3lib_div::_GP('effects');
+		$this->parametersEncoded = implode(t3lib_div::_GP('parameters'));
 		$this->frame = t3lib_div::_GP('frame');
-		$this->bodyTag = t3lib_div::_GP('bodyTag');
-		$this->title = t3lib_div::_GP('title');
-		$this->wrap = t3lib_div::_GP('wrap');
 		$this->md5 = t3lib_div::_GP('md5');
-		$this->contentHash = t3lib_div::_GP('contentHash');
 
 		// ***********************
 		// Check parameters
@@ -159,39 +155,20 @@ class SC_tslib_showpic {
 		}
 
 			// Chech md5-checksum: If this md5-value does not match the one submitted, then we fail... (this is a kind of security that somebody don't just hit the script with a lot of different parameters
-		$md5_value = md5(
-				$this->file.'|'.
-				$this->width.'|'.
-				$this->height.'|'.
-				$this->effects.'|'.
-				$this->bodyTag.'|'.
-				$this->title.'|'.
-				$this->wrap.'|'.
-				$GLOBALS['TYPO3_CONF_VARS']['SYS']['encryptionKey'].'|');
+		$md5_value = t3lib_div::hmac(
+			implode(
+				'|',
+				array($this->file, $this->parametersEncoded)
+			)
+		);
 
 		if ($md5_value!=$this->md5) {
 			die('Parameter Error: Wrong parameters sent.');
 		}
 
-			// Need to connect to database, because this is used (typo3temp_db_tracking, cached image dimensions).
-		$GLOBALS['TYPO3_DB']->sql_pconnect(TYPO3_db_host, TYPO3_db_username, TYPO3_db_password);
-		$GLOBALS['TYPO3_DB']->sql_select_db(TYPO3_db);
-		if (TYPO3_UseCachingFramework) {
-			$GLOBALS['typo3CacheManager'] = t3lib_div::makeInstance('t3lib_cache_Manager');
-			$GLOBALS['typo3CacheFactory'] = t3lib_div::makeInstance('t3lib_cache_Factory');
-			$GLOBALS['typo3CacheFactory']->setCacheManager($GLOBALS['typo3CacheManager']);
-
-			t3lib_cache::initPageCache();
-			t3lib_cache::initPageSectionCache();
-			t3lib_cache::initContentHashCache();
-		}
-
-			// Check for the new content cache hash
-		if (strlen(t3lib_div::_GP('contentHash')) > 0) {
-			$this->content = t3lib_pageSelect::getHash($this->contentHash);
-			if (is_null($this->content)) {
-				die('Parameter Error: Content not available.');
-			}
+		$parameters = unserialize(base64_decode($this->parametersEncoded));
+		foreach ($parameters as $parameterName => $parameterValue) {
+			$this->$parameterName = $parameterValue;
 		}
 
 		// ***********************
@@ -225,6 +202,10 @@ class SC_tslib_showpic {
 			$img->tempPath = $this->alternativeTempPath;
 		}
 
+		// Need to connect to database, because this is used (typo3temp_db_tracking, cached image dimensions).
+		$GLOBALS['TYPO3_DB']->sql_pconnect(TYPO3_db_host, TYPO3_db_username, TYPO3_db_password);
+		$GLOBALS['TYPO3_DB']->sql_select_db(TYPO3_db);
+
 		if (strstr($this->width.$this->height, 'm')) {$max='m';} else {$max='';}
 
 		$this->height = t3lib_div::intInRange($this->height,0);
@@ -232,14 +213,9 @@ class SC_tslib_showpic {
 		if ($this->frame)	{$this->frame = intval($this->frame);}
 		$imgInfo = $img->imageMagickConvert($this->file,'web',$this->width.$max,$this->height,$img->IMparams($this->effects),$this->frame,'');
 
-		if (strlen($this->content) > 0) {
-				// insert image in cached HTML content
-			if (is_array($imgInfo))	{
-				$this->content = str_replace('###IMAGE###', $img->imgTag($imgInfo), $this->content);
-			}
-		} else {
-				// Create HTML output:
-			$this->content .= '
+			// Create HTML output:
+		$this->content='';
+		$this->content.='
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
 
 <html>
@@ -249,14 +225,13 @@ class SC_tslib_showpic {
 </head>
 		'.($this->bodyTag ? $this->bodyTag : '<body>');
 
-			if (is_array($imgInfo))	{
-				$wrapParts = explode('|',$this->wrap);
-				$this->content.=trim($wrapParts[0]).$img->imgTag($imgInfo).trim($wrapParts[1]);
-			}
-			$this->content.='
+		if (is_array($imgInfo))	{
+			$wrapParts = explode('|',$this->wrap);
+			$this->content.=trim($wrapParts[0]).$img->imgTag($imgInfo).trim($wrapParts[1]);
+		}
+		$this->content.='
 		</body>
 		</html>';
-		}
 	}
 
 	/**
