@@ -103,6 +103,7 @@ class Tx_Extbase_Dispatcher {
 			t3lib_div::sysLog('Extbase was not able to dispatch the request. No configuration.', 'extbase', t3lib_div::SYSLOG_SEVERITY_ERROR);
 			return $content;
 		}
+		
 		$this->initializeConfigurationManagerAndFrameworkConfiguration($configuration);
 
 		$requestBuilder = t3lib_div::makeInstance('Tx_Extbase_MVC_Web_RequestBuilder');
@@ -111,6 +112,7 @@ class Tx_Extbase_Dispatcher {
 		if (isset($this->cObj->data) && is_array($this->cObj->data)) {
 			// we need to check the above conditions as cObj is not available in Backend.
 			$request->setContentObjectData($this->cObj->data);
+			$request->setIsCached($this->cObj->getUserObjectType() == tslib_cObj::OBJECTTYPE_USER);
 		}
 		$response = t3lib_div::makeInstance('Tx_Extbase_MVC_Web_Response');
 
@@ -142,14 +144,10 @@ class Tx_Extbase_Dispatcher {
 
 		self::$reflectionService->shutdown();
 		
-		if (substr($response->getStatus(), 0, 3) === '303') {
-			$response->sendHeaders();
-			exit;
-		}
-
 		if (count($response->getAdditionalHeaderData()) > 0) {
 			$GLOBALS['TSFE']->additionalHeaderData[$request->getControllerExtensionName()] = implode("\n", $response->getAdditionalHeaderData());
 		}
+		$response->sendHeaders();
 		$this->timeTrackPull();
 		return $response->getContent();
 	}
@@ -196,7 +194,7 @@ class Tx_Extbase_Dispatcher {
 		} catch (t3lib_cache_exception_NoSuchCache $exception) {
 			$GLOBALS['typo3CacheFactory']->create(
 				'cache_extbase_reflection',
-				't3lib_cache_frontend_VariableFrontend',
+				$GLOBALS['TYPO3_CONF_VARS']['SYS']['caching']['cacheConfigurations']['cache_extbase_reflection']['frontend'],
 				$GLOBALS['TYPO3_CONF_VARS']['SYS']['caching']['cacheConfigurations']['cache_extbase_reflection']['backend'],
 				$GLOBALS['TYPO3_CONF_VARS']['SYS']['caching']['cacheConfigurations']['cache_extbase_reflection']['options']
 			);
@@ -231,11 +229,12 @@ class Tx_Extbase_Dispatcher {
 		$propertyMapper = t3lib_div::makeInstance('Tx_Extbase_Property_Mapper');
 		$propertyMapper->injectReflectionService(self::$reflectionService);
 		$controller->injectPropertyMapper($propertyMapper);
-		$controller->injectSettings(self::$extbaseFrameworkConfiguration['settings']);
+		
+		$controller->injectSettings(is_array(self::$extbaseFrameworkConfiguration['settings']) ? self::$extbaseFrameworkConfiguration['settings'] : array());
 
-		$flashMessages = t3lib_div::makeInstance('Tx_Extbase_MVC_Controller_FlashMessages'); // singleton
-		$flashMessages->reset();
-		$controller->injectFlashMessages($flashMessages);
+		$flashMessageContainer = t3lib_div::makeInstance('Tx_Extbase_MVC_Controller_FlashMessages'); // singleton
+		$flashMessageContainer->reset();
+		$controller->injectFlashMessageContainer($flashMessageContainer);
 
 		$objectManager = t3lib_div::makeInstance('Tx_Extbase_Object_Manager');
 		$validatorResolver = t3lib_div::makeInstance('Tx_Extbase_Validation_ValidatorResolver');
@@ -255,25 +254,26 @@ class Tx_Extbase_Dispatcher {
 	public static function getPersistenceManager() {
 		if (self::$persistenceManager === NULL) {
 			$identityMap = t3lib_div::makeInstance('Tx_Extbase_Persistence_IdentityMap');
+			$persistenceSession = t3lib_div::makeInstance('Tx_Extbase_Persistence_Session'); // singleton
 
 			$dataMapper = t3lib_div::makeInstance('Tx_Extbase_Persistence_Mapper_DataMapper'); // singleton
 			$dataMapper->injectIdentityMap($identityMap);
+			$dataMapper->injectSession($persistenceSession);
 			$dataMapper->injectReflectionService(self::$reflectionService);
-
+			
 			$storageBackend = t3lib_div::makeInstance('Tx_Extbase_Persistence_Storage_Typo3DbBackend', $GLOBALS['TYPO3_DB']); // singleton
 			$storageBackend->injectDataMapper($dataMapper);
 
-			$qomFactory = t3lib_div::makeInstance('Tx_Extbase_Persistence_QOM_QueryObjectModelFactory', $storageBackend, $dataMapper);
-
-			$persistenceSession = t3lib_div::makeInstance('Tx_Extbase_Persistence_Session'); // singleton
+			$qomFactory = t3lib_div::makeInstance('Tx_Extbase_Persistence_QOM_QueryObjectModelFactory', $storageBackend);
+			
+			$dataMapper->setQomFactory($qomFactory);
 
 			$persistenceBackend = t3lib_div::makeInstance('Tx_Extbase_Persistence_Backend', $persistenceSession, $storageBackend); // singleton
 			$persistenceBackend->injectDataMapper($dataMapper);
 			$persistenceBackend->injectIdentityMap($identityMap);
 			$persistenceBackend->injectReflectionService(self::$reflectionService);
 			$persistenceBackend->injectQueryFactory(t3lib_div::makeInstance('Tx_Extbase_Persistence_QueryFactory'));
-			$persistenceBackend->injectQOMFactory($qomFactory);
-			$persistenceBackend->injectValueFactory(t3lib_div::makeInstance('Tx_Extbase_Persistence_ValueFactory'));
+			$persistenceBackend->injectQomFactory($qomFactory);
 
 			$objectManager = t3lib_div::makeInstance('Tx_Extbase_Object_Manager'); // singleton
 
