@@ -14,7 +14,7 @@ else
 	#replace login
 $TCA['tt_content']['types']['login']['showitem']='CType;;4;;1-1-1, hidden, header;;3;;2-2-2, linkToTop;;;;3-3-3,
 							--div--;LLL:EXT:cms/locallang_ttc.xml:CType.I.14, pi_flexform;;;;1-1-1,
-							--div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, starttime, endtime';
+							--div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, starttime, endtime, fe_group';
 
 	// Adds the redirect field to the fe_groups table
 $tempColumns = array(
