@@ -27,7 +27,7 @@
 /*
  * Remove Format Plugin for TYPO3 htmlArea RTE
  *
- * TYPO3 SVN ID: $Id: remove-format.js 7099 2010-03-11 22:13:50Z stan $
+ * TYPO3 SVN ID: $Id: remove-format.js 7566 2010-05-08 03:11:17Z stan $
  */
 RemoveFormat = HTMLArea.Plugin.extend({
 
@@ -44,7 +44,7 @@ RemoveFormat = HTMLArea.Plugin.extend({
 		 * Registering plugin "About" information
 		 */
 		var pluginInformation = {
-			version		: "1.6",
+			version		: "1.7",
 			developer	: "Stanislas Rolland",
 			developerUrl	: "http://www.sjbr.ca/",
 			copyrightOwner	: "Stanislas Rolland",
@@ -116,7 +116,7 @@ RemoveFormat = HTMLArea.Plugin.extend({
 						// Remove font, b, strong, i, em, u, strike, span and other inline tags
 					html = html.replace(/<\/?(abbr|acronym|b[^a-zA-Z]|big|cite|code|em[^a-zA-Z]|font|i[^a-zA-Z]|q|s[^a-zA-Z]|samp|small|span|strike|strong|sub|sup|tt|u[^a-zA-Z]|var)[^>]*>/gi, "");
 						// Keep tags, strip attributes
-					html = html.replace(/ style=\"[^>\"]*\"/gi, "").replace(/ (class|align|cellpadding|cellspacing|frame|bgcolor)=(([^>\s\"]+)|(\"[^>\"]*\"))/gi, "");
+					html = html.replace(/[ \t\n\r]+(style|class|align|cellpadding|cellspacing|frame|bgcolor)=\"[^>\"]*\"/gi, "");
 				}
 
 				if (param["images"] == true) {
@@ -126,11 +126,11 @@ RemoveFormat = HTMLArea.Plugin.extend({
 
 				if (param["ms_formatting"] == true) {
 						// Make one line
-					html = html.replace(/(\r\n|\n|\r)/g, " ");
+					html = html.replace(/[ \r\n\t]+/g, " ");
 						// Clean up tags
 					html = html.replace(/<(b|strong|i|em|p|li|ul) [^>]*>/gi, "<$1>");
 						// Keep tags, strip attributes
-					html = html.replace(/ style=\"[^>\"]*\"/gi, "").replace(/ (class|align)=(([^>\s\"]+)|(\"[^>\"]*\"))/gi, "");
+					html = html.replace(/ (style|class|align)=\"[^>\"]*\"/gi, "");
 						// kill unwanted tags: span, div, ?xml:, st1:, [a-z]:, meta, link
 					html = html.replace(/<\/?span[^>]*>/gi, "").
 						replace(/<\/?div[^>]*>/gi, "").
@@ -144,8 +144,8 @@ RemoveFormat = HTMLArea.Plugin.extend({
 						replace(/<title[^>]*>.*<\/title[^>]*>/gi, "");
 						// remove comments
 					html = html.replace(/<!--[^>]*>/gi, "");
-						// Remove font elements resets
-					html = html.replace(/<\/(b|big|i|s|small|strike|tt|u)><\1>/gi, "");
+						// Remove inline elements resets
+					html = html.replace(/<\/(b[^a-zA-Z]|big|i[^a-zA-Z]|s[^a-zA-Z]|small|strike|tt|u[^a-zA-Z])><\1>/gi, "");
 						// Remove double tags
 					var oldlen = html.length + 1;
 					while(oldlen > html.length) {
