@@ -116,7 +116,7 @@ class tx_sysaction extends mod_user_task {
 							$res = $GLOBALS['TYPO3_DB']->exec_SELECTquery('*', 'be_users', 'pid=0 AND cruser_id='.intval($this->BE_USER->user['uid']).' AND createdByAction='.intval($actionRow['uid']).t3lib_BEfunc::deleteClause('be_users'), '', 'username');
 							$lines = array();
 							while($uRow = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res))	{
-								$lines[] = "<nobr>".($uRow["uid"]==$userRecord["uid"]?"<b>":"").$this->action_linkUserName(t3lib_iconworks::getIconImage("be_users",$uRow,$this->backPath,'title="uid='.$uRow["uid"].'" hspace="2" align="top"').$uRow["username"]." (".$uRow["realName"].")".($uRow["uid"]==$userRecord["uid"]?"</b>":"")."</nobr>",$actionRow["uid"],$uRow["uid"])."<br>";
+								$lines[] = '<nobr>' . ($uRow['uid'] == $userRecord['uid'] ? '<strong>' : '') . $this->action_linkUserName(t3lib_iconworks::getIconImage('be_users', $uRow, $this->backPath, 'title="uid=' . $uRow['uid'] . '" hspace="2" align="top"') . htmlspecialchars($uRow['username']) . ' (' . htmlspecialchars($uRow['realName']) . ')' . ($uRow['uid'] == $userRecord['uid'] ? '</strong>' : '') . '</nobr>', $actionRow['uid'], $uRow['uid']) . '<br />';
 							}
 							if (count($lines))	{
 								$theCode.= $this->pObj->doc->section($LANG->getLL("action_t1_listOfUsers"),implode("",$lines),0,1);
@@ -160,7 +160,7 @@ class tx_sysaction extends mod_user_task {
 								} else {
 									$p.= $LANG->getLL("lNone");
 								}
-								$actionContent.=t3lib_iconworks::getIconImage("be_users",$userRecord,$this->backPath,'title="'.htmlspecialchars($p).'" hspace=2 align=top').$userRecord["username"]." (".$userRecord["realName"].")";
+								$actionContent .= t3lib_iconworks::getIconImage('be_users', $userRecord, $this->backPath, 'title="' . htmlspecialchars($p) . '" hspace="2" align="top"') . htmlspecialchars($userRecord['username']) . ' (' . htmlspecialchars($userRecord['realName']) . ')';
 							}
 							$actionContent.=$this->pObj->doc->table($formA);
 							$theCode.= $this->pObj->doc->section($LANG->getLL($newFlag?"action_Create":"action_Update"),$actionContent,0,1);
@@ -307,7 +307,7 @@ class tx_sysaction extends mod_user_task {
 				$data["be_users"][$key]["disable"]=intval($arr[$key]["disable"]);
 				$data["be_users"][$key]["admin"]=0;
 				$data["be_users"][$key]["usergroup"] = $this->fixUserGroup($data["be_users"][$key]["usergroup"],$actionRow["t1_allowed_groups"],$arr[$key]["usergroups"]);
-				$data["be_users"][$key]["db_mountpoints"]=$arr[$key]["db_mountpoints"];
+				$data["be_users"][$key]["db_mountpoints"]=$this->fixDbMount($arr[$key]["db_mountpoints"]);
 				$data["be_users"][$key]["createdByAction"]=$actionRow["uid"];
 			}
 		} else {
@@ -336,7 +336,7 @@ class tx_sysaction extends mod_user_task {
 					$data["be_users"][$key]["disable"]=intval($arr[$key]["disable"]);
 					$data["be_users"][$key]["admin"]=0;
 					$data["be_users"][$key]["usergroup"] = $this->fixUserGroup($beRec["usergroup"],$actionRow["t1_allowed_groups"],$arr[$key]["usergroups"]);
-					$data["be_users"][$key]["db_mountpoints"]=$arr[$key]["db_mountpoints"];
+					$data["be_users"][$key]["db_mountpoints"]=$this->fixDbMount($arr[$key]["db_mountpoints"]);
 					$nId=$key;
 				}
 			}
@@ -368,6 +368,12 @@ class tx_sysaction extends mod_user_task {
 			return $prefix.$username;
 		} else return false;
 	}
+	/**
+	 * @param  array $curUserGroup	Group array in which the user is already in
+	 * @param  array $allowedGroups	Groups this task allows the be users to be in
+	 * @param  array $inGroups	List of groups the user wants to be in, comes from $_POST
+	 * @return string
+	 */
 	function fixUserGroup($curUserGroup,$allowedGroups,$inGroups)	{
 			// User group:
 			// All current groups:
@@ -382,6 +388,7 @@ class tx_sysaction extends mod_user_task {
 		if (is_array($inGroups))	{
 			reset($inGroups);
 			while(list(,$gu)=each($inGroups))	{
+				$gu = intval($gu);
 				$checkGr = t3lib_BEfunc::getRecord("be_groups",$gu);
 				if (is_array($checkGr) && in_array($gu,$grList))	{
 					$cGroups[]=$gu;
@@ -390,6 +397,53 @@ class tx_sysaction extends mod_user_task {
 		}
 		return implode(",",$cGroups);
 	}
+
+	/**
+	 * Clean the to be applied DB-Mounts from not allowed ones
+	 *
+	 * @param	string		$appliedDbMounts: List of pages like pages_123,pages_456
+	 * @return	string		Cleaned list
+	 */
+	protected function fixDbMount($appliedDbMounts) {
+		if (!empty($appliedDbMounts) && !$GLOBALS['BE_USER']->isAdmin()) {
+			$cleanDbMountList = array();
+			$dbMounts = t3lib_div::trimExplode(',', $appliedDbMounts, 1);
+
+				// walk through every wanted DB-Mount and check if it is allowed for the current user
+			foreach ($dbMounts as $dbMount) {
+				$uid = intval(substr($dbMount,  (strrpos($dbMount, '_') + 1)));
+				$page = t3lib_BEfunc::getRecord('pages', $uid);
+
+					// check rootline and access rights
+				if ($this->checkRootline($uid) && $GLOBALS['BE_USER']->calcPerms($page)) {
+					$cleanDbMountList[] = 'pages_' . $uid;
+				}
+
+			}
+			$appliedDbMounts = implode(',', $cleanDbMountList);
+		}
+		return $appliedDbMounts;
+	}
+
+	/**
+	 * Check if a page is inside the rootline the current user can see
+	 *
+	 * @param	int		$pageId: Id of the the page to be checked
+	 * @return	boolean	Access to the page
+	 */
+	protected function checkRootline($pageId) {
+		$access = FALSE;
+
+		$dbMounts =  array_flip(explode(',', trim($GLOBALS['BE_USER']->dataLists['webmount_list'], ',')));
+		$rootline = t3lib_BEfunc::BEgetRootLine($pageId);
+		foreach ($rootline as $page) {
+			if (isset($dbMounts[$page['uid']]) && !$access) {
+				$access = TRUE;
+			}
+		}
+		return $access;
+	}
+
 	function action_createDir($uid)	{
 		$path = $this->action_getUserMainDir();
 		if ($path)	{
