@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 2007 Stephane Schitter <stephane.schitter@free.fr>
+*  (c) 2007-2009 Stephane Schitter <stephane.schitter@free.fr>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -31,7 +31,6 @@ require_once($BACK_PATH.'template.php');
 require_once($BACK_PATH.'mod/tools/em/class.em_unzip.php');
 
 $LANG->includeLLFile('EXT:tsconfig_help/mod1/locallang.xml');
-require_once(PATH_t3lib.'class.t3lib_scbase.php');
 $BE_USER->modAccess($MCONF,1);	// This checks permissions and exits if the users has no permission for entry.
 // DEFAULT initialization of a module [END]
 
@@ -92,11 +91,10 @@ class tx_tsconfighelp_module1 extends t3lib_SCbase {
 		$this->doc = t3lib_div::makeInstance('template');
 		$this->doc->backPath = $BACK_PATH;
 		$this->doc->setModuleTemplate('templates/tsconfig_help.html');
-		$this->doc->docType = 'xhtml_trans';
 
 		if ($access || $BE_USER->user['admin'])	{
 
-			$this->doc->form = '<form action="" method="POST">';
+			$this->doc->form = '<form action="" method="post">';
 
 				// JavaScript
 			$this->doc->JScode = '
@@ -114,7 +112,7 @@ class tx_tsconfighelp_module1 extends t3lib_SCbase {
 				</script>
 			';
 
-			$headerSection = $this->doc->getHeader('pages',$this->pageinfo,$this->pageinfo['_thePath']).'<br />'.$LANG->sL('LLL:EXT:lang/locallang_core.xml:labels.path').': '.t3lib_div::fixed_lgd_pre($this->pageinfo['_thePath'],50);
+			$headerSection = $this->doc->getHeader('pages',$this->pageinfo,$this->pageinfo['_thePath']).'<br />'.$LANG->sL('LLL:EXT:lang/locallang_core.xml:labels.path').': '.t3lib_div::fixed_lgd_cs($this->pageinfo['_thePath'],-50);
 
 			$this->content .= $this->doc->header($LANG->getLL('title'));
 			$this->content .= $this->doc->spacer(5);
@@ -187,86 +185,82 @@ class tx_tsconfighelp_module1 extends t3lib_SCbase {
 				$content = '<div align="left"><strong>'.$LANG->getLL('referenceExplanation').'</strong></div>';
 				$content .= '<p>'.$LANG->getLL('referenceExplanationDetailed').'</p><br />';
 				$this->content .= $this->doc->section($LANG->getLL('displayReferences'),$content,0,1);
-				$this->content .= '<a href="#" onClick="vHWin=window.open(\''.$BACK_PATH.'wizard_tsconfig.php?mode=tsref&P[formName]=editForm\',\'popUp\',\'height=500,width=780,status=0,menubar=0,scrollbars=1\');vHWin.focus();return false;"><img '.t3lib_iconWorks::skinImg($BACK_PATH, 'gfx/wizard_tsconfig.gif', 'width="22" height="27"').' border="0" title="TSref reference"> TSREF</a><br />';
-				$this->content .= '<a href="#" onClick="vHWin=window.open(\''.$BACK_PATH.'wizard_tsconfig.php?mode=beuser&P[formName]=editForm\',\'popUp\',\'height=500,width=780,status=0,menubar=0,scrollbars=1\');vHWin.focus();return false;"><img '.t3lib_iconWorks::skinImg($BACK_PATH, 'gfx/wizard_tsconfig.gif', 'width="22" height="27"').' border="0" title="TSref reference"> USER TSCONFIG</a><br />';
-				$this->content .= '<a href="#" onClick="vHWin=window.open(\''.$BACK_PATH.'wizard_tsconfig.php?mode=page&P[formName]=editForm\',\'popUp\',\'height=500,width=780,status=0,menubar=0,scrollbars=1\');vHWin.focus();return false;"><img '.t3lib_iconWorks::skinImg($BACK_PATH, 'gfx/wizard_tsconfig.gif', 'width="22" height="27"').' border="0" title="TSref reference"> PAGE TSCONFIG</a><br />';
+				$this->content .= '<a href="#" onclick="vHWin=window.open(\''.$BACK_PATH.'wizard_tsconfig.php?mode=tsref&amp;P[formName]=editForm\',\'popUp\',\'height=500,width=780,status=0,menubar=0,scrollbars=1\');vHWin.focus();return false;"><img '.t3lib_iconWorks::skinImg($BACK_PATH, 'gfx/wizard_tsconfig.gif', 'width="22" height="27"').' border="0" title="TSref reference" alt="TSref reference" /> TSREF</a><br />';
+				$this->content .= '<a href="#" onclick="vHWin=window.open(\''.$BACK_PATH.'wizard_tsconfig.php?mode=beuser&amp;P[formName]=editForm\',\'popUp\',\'height=500,width=780,status=0,menubar=0,scrollbars=1\');vHWin.focus();return false;"><img '.t3lib_iconWorks::skinImg($BACK_PATH, 'gfx/wizard_tsconfig.gif', 'width="22" height="27"').' border="0" title="TSref reference" alt="TSref reference" /> USER TSCONFIG</a><br />';
+				$this->content .= '<a href="#" onclick="vHWin=window.open(\''.$BACK_PATH.'wizard_tsconfig.php?mode=page&amp;P[formName]=editForm\',\'popUp\',\'height=500,width=780,status=0,menubar=0,scrollbars=1\');vHWin.focus();return false;"><img '.t3lib_iconWorks::skinImg($BACK_PATH, 'gfx/wizard_tsconfig.gif', 'width="22" height="27"').' border="0" title="TSref reference" alt="TSref reference" /> PAGE TSCONFIG</a><br />';
 			break;
 
 			case 2:
 				if ($GLOBALS['BE_USER']->user['admin'])	{
-					if ($GLOBALS['TYPO3_OS'] === 'WIN') {
-						$this->content .= '<p>'.$LANG->getLL('noRebuildOnWindows').'</p><br />';
-					} else {
-						if (t3lib_div::_GP('_rebuild'))	{
-								// remove all data from the database
-							$this->purgeSQLContents();
+					if (t3lib_div::_GP('_rebuild'))	{
+							// remove all data from the database
+						$this->purgeSQLContents();
 
-								// get all loaded extension keys
-							$extArray = $TYPO3_LOADED_EXT;
+							// get all loaded extension keys
+						$extArray = $TYPO3_LOADED_EXT;
 
-							$content = '<div align="left"><strong>'.$LANG->getLL('loadedTSfrom').'</strong></div><br />';
+						$content = '<div align="left"><strong>'.$LANG->getLL('loadedTSfrom').'</strong></div><br />';
 
-								// parse the extension names only (no need for all details from the TYPO3_LOADED_EXT table
-							foreach ($extArray as $extName => $dummy)	{
-									// check that the extension is really loaded (which should always be the case)
-								if (t3lib_extMgm::isLoaded($extName))	{
-										// extract the content.xml from the manual.sxw ZIP file
-									$manual = $this->getZIPFileContents(t3lib_extMgm::extPath($extName).'doc/manual.sxw', 'content.xml');
+							// parse the extension names only (no need for all details from the TYPO3_LOADED_EXT table
+						foreach ($extArray as $extName => $dummy)	{
+								// check that the extension is really loaded (which should always be the case)
+							if (t3lib_extMgm::isLoaded($extName))	{
+									// extract the content.xml from the manual.sxw ZIP file
+								$manual = $this->getZIPFileContents(t3lib_extMgm::extPath($extName).'doc/manual.sxw', 'content.xml');
 
-										// check if the manual file actually exists and if the content.xml could be loaded
-									if ($manual != '')	{
-											// if the manual file exists, proceed with the load into the SQL database
-										$content .= '<p>Extension '.$extName.'...';
+									// check if the manual file actually exists and if the content.xml could be loaded
+								if ($manual != '')	{
+										// if the manual file exists, proceed with the load into the SQL database
+									$content .= '<p>Extension '.$extName.'...';
 
-											// run the extraction processing and import the data into SQL. Return the number of TS tables found in the open office document
-										$number = $this->loadExtensionManual($extName, $manual);
+										// run the extraction processing and import the data into SQL. Return the number of TS tables found in the open office document
+									$number = $this->loadExtensionManual($extName, $manual);
 
-											// print a status message with a link to the openoffice manual
-										$content .= $number.' '.$LANG->getLL('sections').' (<a href="'.t3lib_div::getIndpEnv('TYPO3_SITE_URL').TYPO3_mainDir.t3lib_extMgm::extRelPath($extName).'doc/manual.sxw">manual</a>)</p>';
-									}
-								} else	{
-										// this should never happen!
-									die ("Fatal error : loaded extension not actually loaded? Please file a bug report at http://bugs.typo3.org!");
+										// print a status message with a link to the openoffice manual
+									$content .= $number.' '.$LANG->getLL('sections').' (<a href="'.t3lib_div::getIndpEnv('TYPO3_SITE_URL').TYPO3_mainDir.t3lib_extMgm::extRelPath($extName).'doc/manual.sxw">manual</a>)</p>';
 								}
-							}
-
-							$this->content .= $this->doc->section($LANG->getLL('rebuildTS'),$content.'<br />',0,1);
-
-								// Issue warnings about duplicate or empty obj_strings, if any
-								// An obj_string should be unique. It should appear in only one extension manual and then only once
-								// If the sum of all occurrences of a given obj_string is more than one, issue a list of duplicate entries as a warning
-							$duplicateWarnings = '';
-							$emptyWarnings = '';
-							foreach ($this->objStringsPerExtension as $obj_string => $extensions)	{
-								if (empty($obj_string))	{
-									$emptyWarnings = '<p class="typo3-red">'.$LANG->getLL('warning_manualsWithoutMarkers');
-									foreach ($extensions as $extensionKey => $counter)	{
-										$emptyWarnings .= ' '.$extensionKey.' ('.$counter.')<br />';
-									}
-									$emptyWarnings .= '</p><br />';
-								} else {
-									if (array_sum($extensions) > 1)	{
-										$duplicateWarnings .= $obj_string.':';
-										foreach ($extensions as $extensionKey => $counter)	{
-											$duplicateWarnings .= ' '.$extensionKey.' ('.$counter.')';
-										}
-										$duplicateWarnings .= '<br />';
-									}
-								}
-							}
-							$warnings = $emptyWarnings;
-							if (!empty($duplicateWarnings))	{
-								$warnings .= '<p class="typo3-red">'.$LANG->getLL('warning_duplicateMarkers').'<br />'.$duplicateWarnings.'</p>';
-							}
-							if (!empty($warnings))	{
-								$this->content .= $this->doc->section($LANG->getLL('updateWarnings'),'<div>'.$warnings.'</div>',0,1);
+							} else	{
+									// this should never happen!
+								die ("Fatal error : loaded extension not actually loaded? Please file a bug report at http://bugs.typo3.org!");
 							}
 						}
 
-						$content = '<p>'.$LANG->getLL('rebuildExplanation').'</p><br />';
-						$content .= $LANG->getLL('rebuild').' <input type="submit" name="_rebuild" value="Rebuild" /><br />';
-						$this->content .= $this->doc->section($LANG->getLL('rebuildTS'),$content,0,1);
+						$this->content .= $this->doc->section($LANG->getLL('rebuildTS'),$content.'<br />',0,1);
+
+							// Issue warnings about duplicate or empty obj_strings, if any
+							// An obj_string should be unique. It should appear in only one extension manual and then only once
+							// If the sum of all occurrences of a given obj_string is more than one, issue a list of duplicate entries as a warning
+						$duplicateWarnings = '';
+						$emptyWarnings = '';
+						foreach ($this->objStringsPerExtension as $obj_string => $extensions)	{
+							if (empty($obj_string))	{
+								$emptyWarnings = '<p class="typo3-red">'.$LANG->getLL('warning_manualsWithoutMarkers');
+								foreach ($extensions as $extensionKey => $counter)	{
+									$emptyWarnings .= ' '.$extensionKey.' ('.$counter.')<br />';
+								}
+								$emptyWarnings .= '</p><br />';
+							} else {
+								if (array_sum($extensions) > 1)	{
+									$duplicateWarnings .= $obj_string.':';
+									foreach ($extensions as $extensionKey => $counter)	{
+										$duplicateWarnings .= ' '.$extensionKey.' ('.$counter.')';
+									}
+									$duplicateWarnings .= '<br />';
+								}
+							}
+						}
+						$warnings = $emptyWarnings;
+						if (!empty($duplicateWarnings))	{
+							$warnings .= '<p class="typo3-red">'.$LANG->getLL('warning_duplicateMarkers').'<br />'.$duplicateWarnings.'</p>';
+						}
+						if (!empty($warnings))	{
+							$this->content .= $this->doc->section($LANG->getLL('updateWarnings'),'<div>'.$warnings.'</div>',0,1);
+						}
 					}
+
+					$content = '<p>'.$LANG->getLL('rebuildExplanation').'</p><br />';
+					$content .= $LANG->getLL('rebuild').' <input type="submit" name="_rebuild" value="Rebuild" /><br />';
+					$this->content .= $this->doc->section($LANG->getLL('rebuildTS'),$content,0,1);
 				} else {
 					$this->content .= '<p>'.$LANG->getLL('adminAccessOnly').'</p><br />';
 				}
@@ -282,7 +276,7 @@ class tx_tsconfighelp_module1 extends t3lib_SCbase {
 	 * @return	string	contents
 	 */
 	function getZIPFileContents($ZIPfile, $filename)	{
-		if (@file_exists($ZIPfile))	{
+		if (file_exists($ZIPfile))	{
 				// Unzipping SXW file, getting filelist:
 			$tempPath = PATH_site.'typo3temp/tx_tsconfighelp_ziptemp/';
 			t3lib_div::mkdir($tempPath);
@@ -308,8 +302,7 @@ class tx_tsconfighelp_module1 extends t3lib_SCbase {
 	 */
 	function unzip($file, $path)	{
 			// we use the unzip class of the Extension Manager here
-		$className = t3lib_div::makeInstanceClassName('em_unzip');
-		$unzip = new $className($file);
+		$unzip = t3lib_div::makeInstance('em_unzip', $file);
 		$ret = $unzip->extract(array('add_path'=>$path));
 		return (is_array($ret));
 	}
